@@ -32,19 +32,8 @@ start_link(IniFiles) ->
 
 init(IniFiles) ->
     Children = [
-        {config,
-            {config, start_link, [IniFiles]},
-            permanent,
-            5000,
-            worker,
-            [config]
-        },
-        {config_event,
-            {gen_event, start_link, [{local, config_event}]},
-            permanent,
-            5000,
-            worker,
-            dynamic
-        }
+        {config, {config, start_link, [IniFiles]}, permanent, 5000, worker, [config]},
+        {config_event, {gen_event, start_link, [{local, config_event}]}, permanent, 5000, worker,
+            dynamic}
     ],
     {ok, {{one_for_one, 5, 10}, Children}}.
