@@ -12,11 +12,9 @@
 
 -module(couch_db_engine).
 
-
 -include("couch_db.hrl").
 -include("couch_db_int.hrl").
 
-
 -type filepath() :: iolist().
 -type docid() :: binary().
 -type rev() :: {non_neg_integer(), binary()}.
@@ -26,75 +24,82 @@
 -type purge_seq() :: non_neg_integer().
 
 -type doc_pair() :: {
-        #full_doc_info{} | not_found,
-        #full_doc_info{} | not_found
-    }.
+    #full_doc_info{} | not_found,
+    #full_doc_info{} | not_found
+}.
 
 -type doc_pairs() :: [doc_pair()].
 
 -type db_open_options() :: [
-        create
-    ].
+    create
+].
 
 -type delete_options() :: [
-        {context, delete | compaction} |
-        sync
-    ].
+    {context, delete | compaction}
+    | sync
+].
 
 -type purge_info() :: {purge_seq(), uuid(), docid(), revs()}.
--type epochs() :: [{Node::atom(), UpdateSeq::non_neg_integer()}].
--type size_info() :: [{Name::atom(), Size::non_neg_integer()}].
+-type epochs() :: [{Node :: atom(), UpdateSeq :: non_neg_integer()}].
+-type size_info() :: [{Name :: atom(), Size :: non_neg_integer()}].
 -type partition_info() :: [
-    {partition, Partition::binary()} |
-    {doc_count, DocCount::non_neg_integer()} |
-    {doc_del_count, DocDelCount::non_neg_integer()} |
-    {sizes, size_info()}
+    {partition, Partition :: binary()}
+    | {doc_count, DocCount :: non_neg_integer()}
+    | {doc_del_count, DocDelCount :: non_neg_integer()}
+    | {sizes, size_info()}
 ].
 
 -type write_stream_options() :: [
-        {buffer_size, Size::pos_integer()} |
-        {encoding, atom()} |
-        {compression_level, non_neg_integer()}
-    ].
+    {buffer_size, Size :: pos_integer()}
+    | {encoding, atom()}
+    | {compression_level, non_neg_integer()}
+].
 
 -type doc_fold_options() :: [
-        {start_key, Key::any()} |
-        {end_key, Key::any()} |
-        {end_key_gt, Key::any()} |
-        {dir, fwd | rev} |
-        include_reductions |
-        include_deleted
-    ].
+    {start_key, Key :: any()}
+    | {end_key, Key :: any()}
+    | {end_key_gt, Key :: any()}
+    | {dir, fwd | rev}
+    | include_reductions
+    | include_deleted
+].
 
 -type changes_fold_options() :: [
-        {dir, fwd | rev}
-    ].
+    {dir, fwd | rev}
+].
 
 -type purge_fold_options() :: [
-        {start_key, Key::any()} |
-        {end_key, Key::any()} |
-        {end_key_gt, Key::any()} |
-        {dir, fwd | rev}
-    ].
+    {start_key, Key :: any()}
+    | {end_key, Key :: any()}
+    | {end_key_gt, Key :: any()}
+    | {dir, fwd | rev}
+].
 
 -type db_handle() :: any().
 
--type doc_fold_fun() :: fun((#full_doc_info{}, UserAcc::any()) ->
-        {ok, NewUserAcc::any()} |
-        {stop, NewUserAcc::any()}).
+-type doc_fold_fun() :: fun(
+    (#full_doc_info{}, UserAcc :: any()) ->
+        {ok, NewUserAcc :: any()}
+        | {stop, NewUserAcc :: any()}
+).
 
--type local_doc_fold_fun() :: fun((#doc{}, UserAcc::any()) ->
-        {ok, NewUserAcc::any()} |
-        {stop, NewUserAcc::any()}).
+-type local_doc_fold_fun() :: fun(
+    (#doc{}, UserAcc :: any()) ->
+        {ok, NewUserAcc :: any()}
+        | {stop, NewUserAcc :: any()}
+).
 
--type changes_fold_fun() :: fun((#doc_info{}, UserAcc::any()) ->
-        {ok, NewUserAcc::any()} |
-        {stop, NewUserAcc::any()}).
-
--type purge_fold_fun() :: fun((purge_info(), UserAcc::any()) ->
-        {ok, NewUserAcc::any()} |
-        {stop, NewUserAcc::any()}).
+-type changes_fold_fun() :: fun(
+    (#doc_info{}, UserAcc :: any()) ->
+        {ok, NewUserAcc :: any()}
+        | {stop, NewUserAcc :: any()}
+).
 
+-type purge_fold_fun() :: fun(
+    (purge_info(), UserAcc :: any()) ->
+        {ok, NewUserAcc :: any()}
+        | {stop, NewUserAcc :: any()}
+).
 
 % This is called by couch_server to determine which
 % engine should be used for the given database. DbPath
@@ -102,8 +107,7 @@
 % extension for a given engine. The first engine to
 % return true is the engine that will be used for the
 % database.
--callback exists(DbPath::filepath()) -> boolean().
-
+-callback exists(DbPath :: filepath()) -> boolean().
 
 % This is called by couch_server to delete a database. It
 % is called from inside the couch_server process which
@@ -112,11 +116,11 @@
 % context. Although since this is executed in the context
 % of couch_server it should return relatively quickly.
 -callback delete(
-            RootDir::filepath(),
-            DbPath::filepath(),
-            DelOpts::delete_options()) ->
-        ok | {error, Reason::atom()}.
-
+    RootDir :: filepath(),
+    DbPath :: filepath(),
+    DelOpts :: delete_options()
+) ->
+    ok | {error, Reason :: atom()}.
 
 % This function can be called from multiple contexts. It
 % will either be called just before a call to delete/3 above
@@ -125,11 +129,11 @@
 % remove any temporary files used during compaction that
 % may be used to recover from a failed compaction swap.
 -callback delete_compaction_files(
-            RootDir::filepath(),
-            DbPath::filepath(),
-            DelOpts::delete_options()) ->
-        ok.
-
+    RootDir :: filepath(),
+    DbPath :: filepath(),
+    DelOpts :: delete_options()
+) ->
+    ok.
 
 % This is called from the couch_db_updater:init/1 context. As
 % such this means that it is guaranteed to only have one process
@@ -145,41 +149,36 @@
 % its guaranteed that the handle will only ever be mutated
 % in a single threaded context (ie, within the couch_db_updater
 % process).
--callback init(DbPath::filepath(), db_open_options()) ->
-    {ok, DbHandle::db_handle()}.
-
+-callback init(DbPath :: filepath(), db_open_options()) ->
+    {ok, DbHandle :: db_handle()}.
 
 % This is called in the context of couch_db_updater:terminate/2
 % and as such has the same properties for init/2. It's guaranteed
 % to be consistent for a given database but may be called by many
 % databases concurrently.
--callback terminate(Reason::any(), DbHandle::db_handle()) -> Ignored::any().
-
+-callback terminate(Reason :: any(), DbHandle :: db_handle()) -> Ignored :: any().
 
 % This is called in the context of couch_db_updater:handle_call/3
 % for any message that is unknown. It can be used to handle messages
 % from asynchronous processes like the engine's compactor if it has one.
--callback handle_db_updater_call(Msg::any(), DbHandle::db_handle()) ->
-        {reply, Resp::any(), NewDbHandle::db_handle()} |
-        {stop, Reason::any(), Resp::any(), NewDbHandle::db_handle()}.
-
+-callback handle_db_updater_call(Msg :: any(), DbHandle :: db_handle()) ->
+    {reply, Resp :: any(), NewDbHandle :: db_handle()}
+    | {stop, Reason :: any(), Resp :: any(), NewDbHandle :: db_handle()}.
 
 % This is called in the context of couch_db_updater:handle_info/2
 % and has the same properties as handle_call/3.
--callback handle_db_updater_info(Msg::any(), DbHandle::db_handle()) ->
-    {noreply, NewDbHandle::db_handle()} |
-    {noreply, NewDbHandle::db_handle(), Timeout::timeout()} |
-    {stop, Reason::any(), NewDbHandle::db_handle()}.
-
+-callback handle_db_updater_info(Msg :: any(), DbHandle :: db_handle()) ->
+    {noreply, NewDbHandle :: db_handle()}
+    | {noreply, NewDbHandle :: db_handle(), Timeout :: timeout()}
+    | {stop, Reason :: any(), NewDbHandle :: db_handle()}.
 
 % These functions are called by any process opening or closing
 % a database. As such they need to be able to handle being
 % called concurrently. For example, the legacy engine uses these
 % to add monitors to the main engine process.
--callback incref(DbHandle::db_handle()) -> {ok, NewDbHandle::db_handle()}.
--callback decref(DbHandle::db_handle()) -> ok.
--callback monitored_by(DbHande::db_handle()) -> [pid()].
-
+-callback incref(DbHandle :: db_handle()) -> {ok, NewDbHandle :: db_handle()}.
+-callback decref(DbHandle :: db_handle()) -> ok.
+-callback monitored_by(DbHande :: db_handle()) -> [pid()].
 
 % This is called in the context of couch_db_updater:handle_info/2
 % and should return the timestamp of the last activity of
@@ -187,8 +186,7 @@
 % value would be hard to report its ok to just return the
 % result of os:timestamp/0 as this will just disable idle
 % databases from automatically closing.
--callback last_activity(DbHandle::db_handle()) -> erlang:timestamp().
-
+-callback last_activity(DbHandle :: db_handle()) -> erlang:timestamp().
 
 % All of the get_* functions may be called from many
 % processes concurrently.
@@ -196,25 +194,21 @@
 % The database should make a note of the update sequence when it
 % was last compacted. If the database doesn't need compacting it
 % can just hard code a return value of 0.
--callback get_compacted_seq(DbHandle::db_handle()) ->
-            CompactedSeq::non_neg_integer().
-
+-callback get_compacted_seq(DbHandle :: db_handle()) ->
+    CompactedSeq :: non_neg_integer().
 
 % The number of documents in the database which have all leaf
 % revisions marked as deleted.
--callback get_del_doc_count(DbHandle::db_handle()) ->
-            DelDocCount::non_neg_integer().
-
+-callback get_del_doc_count(DbHandle :: db_handle()) ->
+    DelDocCount :: non_neg_integer().
 
 % This number is reported in the database info properties and
 % as such can be any JSON value.
--callback get_disk_version(DbHandle::db_handle()) -> Version::json().
-
+-callback get_disk_version(DbHandle :: db_handle()) -> Version :: json().
 
 % The number of documents in the database that have one or more
 % leaf revisions not marked as deleted.
--callback get_doc_count(DbHandle::db_handle()) -> DocCount::non_neg_integer().
-
+-callback get_doc_count(DbHandle :: db_handle()) -> DocCount :: non_neg_integer().
 
 % The epochs track which node owned the database starting at
 % a given update sequence. Each time a database is opened it
@@ -222,36 +216,29 @@
 % for the current node it should add an entry that will be
 % written the next time a write is performed. An entry is
 % simply a {node(), CurrentUpdateSeq} tuple.
--callback get_epochs(DbHandle::db_handle()) -> Epochs::epochs().
-
+-callback get_epochs(DbHandle :: db_handle()) -> Epochs :: epochs().
 
 % Get the current purge sequence known to the engine. This
 % value should be updated during calls to purge_docs.
--callback get_purge_seq(DbHandle::db_handle()) -> purge_seq().
-
+-callback get_purge_seq(DbHandle :: db_handle()) -> purge_seq().
 
 % Get the oldest purge sequence known to the engine
--callback get_oldest_purge_seq(DbHandle::db_handle()) -> purge_seq().
-
+-callback get_oldest_purge_seq(DbHandle :: db_handle()) -> purge_seq().
 
 % Get the purged infos limit. This should just return the last
 % value that was passed to set_purged_docs_limit/2.
--callback get_purge_infos_limit(DbHandle::db_handle()) -> pos_integer().
-
+-callback get_purge_infos_limit(DbHandle :: db_handle()) -> pos_integer().
 
 % Get the revision limit. This should just return the last
 % value that was passed to set_revs_limit/2.
--callback get_revs_limit(DbHandle::db_handle()) -> RevsLimit::pos_integer().
-
+-callback get_revs_limit(DbHandle :: db_handle()) -> RevsLimit :: pos_integer().
 
 % Get the current security properties. This should just return
 % the last value that was passed to set_security/2.
--callback get_security(DbHandle::db_handle()) -> SecProps::any().
-
+-callback get_security(DbHandle :: db_handle()) -> SecProps :: any().
 
 % Get the current properties.
--callback get_props(DbHandle::db_handle()) -> Props::[any()].
-
+-callback get_props(DbHandle :: db_handle()) -> Props :: [any()].
 
 % This information is displayed in the database info poperties. It
 % should just be a list of {Name::atom(), Size::non_neg_integer()}
@@ -266,8 +253,7 @@
 %   external - Number of bytes that would be required to represent the
 %              contents outside of the database (for capacity and backup
 %              planning)
--callback get_size_info(DbHandle::db_handle()) -> SizeInfo::size_info().
-
+-callback get_size_info(DbHandle :: db_handle()) -> SizeInfo :: size_info().
 
 % This returns the information for the given partition.
 % It should just be a list of {Name::atom(), Size::non_neg_integer()}
@@ -277,56 +263,49 @@
 %
 %   external - Number of bytes that would be required to represent the
 %              contents of this partition outside of the database
--callback get_partition_info(DbHandle::db_handle(), Partition::binary()) ->
+-callback get_partition_info(DbHandle :: db_handle(), Partition :: binary()) ->
     partition_info().
 
-
 % The current update sequence of the database. The update
 % sequence should be incrememnted for every revision added to
 % the database.
--callback get_update_seq(DbHandle::db_handle()) -> UpdateSeq::non_neg_integer().
-
+-callback get_update_seq(DbHandle :: db_handle()) -> UpdateSeq :: non_neg_integer().
 
 % Whenever a database is created it should generate a
 % persistent UUID for identification in case the shard should
 % ever need to be moved between nodes in a cluster.
--callback get_uuid(DbHandle::db_handle()) -> UUID::binary().
-
+-callback get_uuid(DbHandle :: db_handle()) -> UUID :: binary().
 
 % These functions are only called by couch_db_updater and
 % as such are guaranteed to be single threaded calls. The
 % database should simply store these values somewhere so
 % they can be returned by the corresponding get_* calls.
 
--callback set_revs_limit(DbHandle::db_handle(), RevsLimit::pos_integer()) ->
-        {ok, NewDbHandle::db_handle()}.
+-callback set_revs_limit(DbHandle :: db_handle(), RevsLimit :: pos_integer()) ->
+    {ok, NewDbHandle :: db_handle()}.
 
+-callback set_purge_infos_limit(DbHandle :: db_handle(), Limit :: pos_integer()) ->
+    {ok, NewDbHandle :: db_handle()}.
 
--callback set_purge_infos_limit(DbHandle::db_handle(), Limit::pos_integer()) ->
-        {ok, NewDbHandle::db_handle()}.
-
-
--callback set_security(DbHandle::db_handle(), SecProps::any()) ->
-        {ok, NewDbHandle::db_handle()}.
-
+-callback set_security(DbHandle :: db_handle(), SecProps :: any()) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % This function is only called by couch_db_updater and
 % as such is guaranteed to be single threaded calls. The
 % database should simply store provided property list
 % unaltered.
 
--callback set_props(DbHandle::db_handle(), Props::any()) ->
-        {ok, NewDbHandle::db_handle()}.
-
+-callback set_props(DbHandle :: db_handle(), Props :: any()) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % Set the current update sequence of the database. The intention is to use this
 % when copying a database such that the destination update sequence should
 % match exactly the source update sequence.
 -callback set_update_seq(
-    DbHandle::db_handle(),
-    UpdateSeq::non_neg_integer()) ->
-    {ok, NewDbHandle::db_handle()}.
-
+    DbHandle :: db_handle(),
+    UpdateSeq :: non_neg_integer()
+) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % This function will be called by many processes concurrently.
 % It should return a #full_doc_info{} record or not_found for
@@ -337,9 +316,8 @@
 % were present in the database when the DbHandle was retrieved
 % from couch_server. It is currently unknown what would break
 % if a storage engine deviated from that property.
--callback open_docs(DbHandle::db_handle(), DocIds::[docid()]) ->
-        [#full_doc_info{} | not_found].
-
+-callback open_docs(DbHandle :: db_handle(), DocIds :: [docid()]) ->
+    [#full_doc_info{} | not_found].
 
 % This function will be called by many processes concurrently.
 % It should return a #doc{} record or not_found for every
@@ -349,9 +327,8 @@
 % apply to this function (although this function is called
 % rather less frequently so it may not be as big of an
 % issue).
--callback open_local_docs(DbHandle::db_handle(), DocIds::[docid()]) ->
-        [#doc{} | not_found].
-
+-callback open_local_docs(DbHandle :: db_handle(), DocIds :: [docid()]) ->
+    [#doc{} | not_found].
 
 % This function will be called from many contexts concurrently.
 % The provided RawDoc is a #doc{} record that has its body
@@ -360,18 +337,16 @@
 % This API exists so that storage engines can store document
 % bodies externally from the #full_doc_info{} record (which
 % is the traditional approach and is recommended).
--callback read_doc_body(DbHandle::db_handle(), RawDoc::doc()) ->
-        doc().
-
+-callback read_doc_body(DbHandle :: db_handle(), RawDoc :: doc()) ->
+    doc().
 
 % This function will be called from many contexts concurrently.
 % If the storage engine has a purge_info() record for any of the
 % provided UUIDs, those purge_info() records should be returned. The
 % resulting list should have the same length as the input list of
 % UUIDs.
--callback load_purge_infos(DbHandle::db_handle(), [uuid()]) ->
-        [purge_info() | not_found].
-
+-callback load_purge_infos(DbHandle :: db_handle(), [uuid()]) ->
+    [purge_info() | not_found].
 
 % This function is called concurrently by any client process
 % that is writing a document. It should accept a #doc{}
@@ -382,9 +357,8 @@
 % document bodies in parallel by client processes rather
 % than forcing all compression to occur single threaded
 % in the context of the couch_db_updater process.
--callback serialize_doc(DbHandle::db_handle(), Doc::doc()) ->
-        doc().
-
+-callback serialize_doc(DbHandle :: db_handle(), Doc :: doc()) ->
+    doc().
 
 % This function is called in the context of a couch_db_updater
 % which means its single threaded for the given DbHandle.
@@ -397,9 +371,8 @@
 % The BytesWritten return value is used to determine the number
 % of active bytes in the database which can is used to make
 % a determination of when to compact this database.
--callback write_doc_body(DbHandle::db_handle(), Doc::doc()) ->
-        {ok, FlushedDoc::doc(), BytesWritten::non_neg_integer()}.
-
+-callback write_doc_body(DbHandle :: db_handle(), Doc :: doc()) ->
+    {ok, FlushedDoc :: doc(), BytesWritten :: non_neg_integer()}.
 
 % This function is called from the context of couch_db_updater
 % and as such is guaranteed single threaded for the given
@@ -435,11 +408,11 @@
 % batches are non-deterministic (from the point of view of the
 % client).
 -callback write_doc_infos(
-    DbHandle::db_handle(),
-    Pairs::doc_pairs(),
-    LocalDocs::[#doc{}]) ->
-        {ok, NewDbHandle::db_handle()}.
-
+    DbHandle :: db_handle(),
+    Pairs :: doc_pairs(),
+    LocalDocs :: [#doc{}]
+) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % This function is called from the context of couch_db_updater
 % and as such is guaranteed single threaded for the given
@@ -470,25 +443,22 @@
 % revisions that were requested to be purged. This should be persisted
 % in such a way that we can efficiently load purge_info() by its UUID
 % as well as iterate over purge_info() entries in order of their PurgeSeq.
--callback purge_docs(DbHandle::db_handle(), [doc_pair()], [purge_info()]) ->
-        {ok, NewDbHandle::db_handle()}.
-
+-callback purge_docs(DbHandle :: db_handle(), [doc_pair()], [purge_info()]) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % This function should be called from a single threaded context and
 % should be used to copy purge infos from on database to another
 % when copying a database
--callback copy_purge_infos(DbHandle::db_handle(), [purge_info()]) ->
-        {ok, NewDbHandle::db_handle()}.
-
+-callback copy_purge_infos(DbHandle :: db_handle(), [purge_info()]) ->
+    {ok, NewDbHandle :: db_handle()}.
 
 % This function is called in the context of couch_db_udpater and
 % as such is single threaded for any given DbHandle.
 %
 % This call is made periodically to ensure that the database has
 % stored all updates on stable storage. (ie, here is where you fsync).
--callback commit_data(DbHandle::db_handle()) ->
-        {ok, NewDbHande::db_handle()}.
-
+-callback commit_data(DbHandle :: db_handle()) ->
+    {ok, NewDbHande :: db_handle()}.
 
 % This function is called by multiple processes concurrently.
 %
@@ -502,20 +472,18 @@
 % Currently an engine can elect to not implement these API's
 % by throwing the atom not_supported.
 -callback open_write_stream(
-    DbHandle::db_handle(),
-    Options::write_stream_options()) ->
-        {ok, pid()}.
-
+    DbHandle :: db_handle(),
+    Options :: write_stream_options()
+) ->
+    {ok, pid()}.
 
 % See the documentation for open_write_stream
--callback open_read_stream(DbHandle::db_handle(), StreamDiskInfo::any()) ->
-        {ok, {Module::atom(), ReadStreamState::any()}}.
-
+-callback open_read_stream(DbHandle :: db_handle(), StreamDiskInfo :: any()) ->
+    {ok, {Module :: atom(), ReadStreamState :: any()}}.
 
 % See the documentation for open_write_stream
--callback is_active_stream(DbHandle::db_handle(), ReadStreamState::any()) ->
-        boolean().
-
+-callback is_active_stream(DbHandle :: db_handle(), ReadStreamState :: any()) ->
+    boolean().
 
 % This funciton is called by many processes concurrently.
 %
@@ -567,12 +535,12 @@
 % that actually happening so a storage engine that includes new results
 % between invocations shouldn't have any issues.
 -callback fold_docs(
-    DbHandle::db_handle(),
-    UserFold::doc_fold_fun(),
-    UserAcc::any(),
-    doc_fold_options()) ->
-        {ok, LastUserAcc::any()}.
-
+    DbHandle :: db_handle(),
+    UserFold :: doc_fold_fun(),
+    UserAcc :: any(),
+    doc_fold_options()
+) ->
+    {ok, LastUserAcc :: any()}.
 
 % This function may be called by many processes concurrently.
 %
@@ -580,12 +548,12 @@
 % should only return local documents and the first argument to the
 % user function is a #doc{} record, not a #full_doc_info{}.
 -callback fold_local_docs(
-    DbHandle::db_handle(),
-    UserFold::local_doc_fold_fun(),
-    UserAcc::any(),
-    doc_fold_options()) ->
-        {ok, LastUserAcc::any()}.
-
+    DbHandle :: db_handle(),
+    UserFold :: local_doc_fold_fun(),
+    UserAcc :: any(),
+    doc_fold_options()
+) ->
+    {ok, LastUserAcc :: any()}.
 
 % This function may be called by many processes concurrently.
 %
@@ -608,13 +576,13 @@
 % The only option currently supported by the API is the `dir`
 % option that should behave the same as for fold_docs.
 -callback fold_changes(
-    DbHandle::db_handle(),
-    StartSeq::non_neg_integer(),
-    UserFold::changes_fold_fun(),
-    UserAcc::any(),
-    changes_fold_options()) ->
-        {ok, LastUserAcc::any()}.
-
+    DbHandle :: db_handle(),
+    StartSeq :: non_neg_integer(),
+    UserFold :: changes_fold_fun(),
+    UserAcc :: any(),
+    changes_fold_options()
+) ->
+    {ok, LastUserAcc :: any()}.
 
 % This function may be called by many processes concurrently.
 %
@@ -623,13 +591,13 @@
 %
 % The StartPurgeSeq parameter indicates where the fold should start *after*.
 -callback fold_purge_infos(
-    DbHandle::db_handle(),
-    StartPurgeSeq::purge_seq(),
-    UserFold::purge_fold_fun(),
-    UserAcc::any(),
-    purge_fold_options()) ->
-        {ok, LastUserAcc::any()}.
-
+    DbHandle :: db_handle(),
+    StartPurgeSeq :: purge_seq(),
+    UserFold :: purge_fold_fun(),
+    UserAcc :: any(),
+    purge_fold_options()
+) ->
+    {ok, LastUserAcc :: any()}.
 
 % This function may be called by many processes concurrently.
 %
@@ -647,10 +615,10 @@
 % _active_tasks entry if the storage engine isn't accounted for by the
 % client.
 -callback count_changes_since(
-    DbHandle::db_handle(),
-    UpdateSeq::non_neg_integer()) ->
-        TotalChanges::non_neg_integer().
-
+    DbHandle :: db_handle(),
+    UpdateSeq :: non_neg_integer()
+) ->
+    TotalChanges :: non_neg_integer().
 
 % This function is called in the context of couch_db_updater and as
 % such is guaranteed to be single threaded for the given DbHandle.
@@ -666,12 +634,12 @@
 % must be the same engine that started the compaction and CompactInfo
 % is an arbitrary term that's passed to finish_compaction/4.
 -callback start_compaction(
-    DbHandle::db_handle(),
-    DbName::binary(),
-    Options::db_open_options(),
-    Parent::pid()) ->
-        {ok, NewDbHandle::db_handle(), CompactorPid::pid()}.
-
+    DbHandle :: db_handle(),
+    DbName :: binary(),
+    Options :: db_open_options(),
+    Parent :: pid()
+) ->
+    {ok, NewDbHandle :: db_handle(), CompactorPid :: pid()}.
 
 % This function is called in the context of couch_db_udpater and as
 % such is guarnateed to be single threaded for the given DbHandle.
@@ -683,17 +651,18 @@
 % to update the DbHandle state of the couch_db_updater it can as
 % finish_compaction/4 is called in the context of the couch_db_updater.
 -callback finish_compaction(
-    OldDbHandle::db_handle(),
-    DbName::binary(),
-    Options::db_open_options(),
-    CompactInfo::any()) ->
-        {ok, CompactedDbHandle::db_handle(), CompactorPid::pid() | undefined}.
-
+    OldDbHandle :: db_handle(),
+    DbName :: binary(),
+    Options :: db_open_options(),
+    CompactInfo :: any()
+) ->
+    {ok, CompactedDbHandle :: db_handle(), CompactorPid :: pid() | undefined}.
 
 -export([
     exists/2,
     delete/4,
     delete_compaction_files/4,
+    is_compacting/2,
 
     init/3,
     terminate/2,
@@ -757,34 +726,32 @@
     trigger_on_compact/1
 ]).
 
-
 exists(Engine, DbPath) ->
     Engine:exists(DbPath).
 
-
 delete(Engine, RootDir, DbPath, DelOpts) when is_list(DelOpts) ->
     Engine:delete(RootDir, DbPath, DelOpts).
 
-
-delete_compaction_files(Engine, RootDir, DbPath, DelOpts)
-        when is_list(DelOpts) ->
+delete_compaction_files(Engine, RootDir, DbPath, DelOpts) when
+    is_list(DelOpts)
+->
     Engine:delete_compaction_files(RootDir, DbPath, DelOpts).
 
+is_compacting(Engine, FilePath) ->
+    Engine:is_compacting(FilePath).
 
 init(Engine, DbPath, Options) ->
     case Engine:init(DbPath, Options) of
-         {ok, EngineState} ->
-             {ok, {Engine, EngineState}};
-         Error ->
-             throw(Error)
+        {ok, EngineState} ->
+            {ok, {Engine, EngineState}};
+        Error ->
+            throw(Error)
     end.
 
-
 terminate(Reason, #db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:terminate(Reason, EngineState).
 
-
 handle_db_updater_call(Msg, _From, #db{} = Db) ->
     #db{
         engine = {Engine, EngineState}
@@ -796,7 +763,6 @@ handle_db_updater_call(Msg, _From, #db{} = Db) ->
             {stop, Reason, Resp, Db#db{engine = {Engine, NewState}}}
     end.
 
-
 handle_db_updater_info(Msg, #db{} = Db) ->
     #db{
         name = Name,
@@ -812,98 +778,79 @@ handle_db_updater_info(Msg, #db{} = Db) ->
             {stop, Reason, Db#db{engine = {Engine, NewState}}}
     end.
 
-
 incref(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewState} = Engine:incref(EngineState),
     {ok, Db#db{engine = {Engine, NewState}}}.
 
-
 decref(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:decref(EngineState).
 
-
 monitored_by(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:monitored_by(EngineState).
 
-
 last_activity(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:last_activity(EngineState).
 
-
 get_engine(#db{} = Db) ->
     #db{engine = {Engine, _}} = Db,
     Engine.
 
-
 get_compacted_seq(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_compacted_seq(EngineState).
 
-
 get_del_doc_count(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_del_doc_count(EngineState).
 
-
 get_disk_version(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_disk_version(EngineState).
 
-
 get_doc_count(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_doc_count(EngineState).
 
-
 get_epochs(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_epochs(EngineState).
 
-
 get_purge_seq(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_purge_seq(EngineState).
 
-
 get_oldest_purge_seq(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_oldest_purge_seq(EngineState).
 
-
 get_purge_infos_limit(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_purge_infos_limit(EngineState).
 
-
 get_revs_limit(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_revs_limit(EngineState).
 
-
 get_security(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_security(EngineState).
 
-
 get_props(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_props(EngineState).
 
-
 get_size_info(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_size_info(EngineState).
 
-
 get_partition_info(#db{} = Db, Partition) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_partition_info(EngineState, Partition).
 
-
 get_update_seq(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_update_seq(EngineState).
@@ -912,134 +859,113 @@ get_uuid(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:get_uuid(EngineState).
 
-
 set_revs_limit(#db{} = Db, RevsLimit) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:set_revs_limit(EngineState, RevsLimit),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 set_purge_infos_limit(#db{} = Db, PurgedDocsLimit) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:set_purge_infos_limit(EngineState, PurgedDocsLimit),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 set_security(#db{} = Db, SecProps) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:set_security(EngineState, SecProps),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 set_props(#db{} = Db, Props) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:set_props(EngineState, Props),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 set_update_seq(#db{} = Db, UpdateSeq) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:set_update_seq(EngineState, UpdateSeq),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 open_docs(#db{} = Db, DocIds) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:open_docs(EngineState, DocIds).
 
-
 open_local_docs(#db{} = Db, DocIds) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:open_local_docs(EngineState, DocIds).
 
-
 read_doc_body(#db{} = Db, RawDoc) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:read_doc_body(EngineState, RawDoc).
 
-
 load_purge_infos(#db{} = Db, UUIDs) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:load_purge_infos(EngineState, UUIDs).
 
-
 serialize_doc(#db{} = Db, #doc{} = Doc) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:serialize_doc(EngineState, Doc).
 
-
 write_doc_body(#db{} = Db, #doc{} = Doc) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:write_doc_body(EngineState, Doc).
 
-
 write_doc_infos(#db{} = Db, DocUpdates, LocalDocs) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:write_doc_infos(EngineState, DocUpdates, LocalDocs),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 purge_docs(#db{} = Db, DocUpdates, Purges) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:purge_docs(
-        EngineState, DocUpdates, Purges),
+        EngineState, DocUpdates, Purges
+    ),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 copy_purge_infos(#db{} = Db, Purges) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:copy_purge_infos(
-        EngineState, Purges),
+        EngineState, Purges
+    ),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 commit_data(#db{} = Db) ->
     #db{engine = {Engine, EngineState}} = Db,
     {ok, NewSt} = Engine:commit_data(EngineState),
     {ok, Db#db{engine = {Engine, NewSt}}}.
 
-
 open_write_stream(#db{} = Db, Options) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:open_write_stream(EngineState, Options).
 
-
 open_read_stream(#db{} = Db, StreamDiskInfo) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:open_read_stream(EngineState, StreamDiskInfo).
 
-
 is_active_stream(#db{} = Db, ReadStreamState) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:is_active_stream(EngineState, ReadStreamState).
 
-
 fold_docs(#db{} = Db, UserFun, UserAcc, Options) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:fold_docs(EngineState, UserFun, UserAcc, Options).
 
-
 fold_local_docs(#db{} = Db, UserFun, UserAcc, Options) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:fold_local_docs(EngineState, UserFun, UserAcc, Options).
 
-
 fold_changes(#db{} = Db, StartSeq, UserFun, UserAcc, Options) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:fold_changes(EngineState, StartSeq, UserFun, UserAcc, Options).
 
-
 fold_purge_infos(#db{} = Db, StartPurgeSeq, UserFun, UserAcc, Options) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:fold_purge_infos(
-            EngineState, StartPurgeSeq, UserFun, UserAcc, Options).
-
+        EngineState, StartPurgeSeq, UserFun, UserAcc, Options
+    ).
 
 count_changes_since(#db{} = Db, StartSeq) ->
     #db{engine = {Engine, EngineState}} = Db,
     Engine:count_changes_since(EngineState, StartSeq).
 
-
 start_compaction(#db{} = Db) ->
     #db{
         engine = {Engine, EngineState},
@@ -1047,50 +973,53 @@ start_compaction(#db{} = Db) ->
         options = Options
     } = Db,
     {ok, NewEngineState, Pid} = Engine:start_compaction(
-            EngineState, DbName, Options, self()),
+        EngineState, DbName, Options, self()
+    ),
     {ok, Db#db{
         engine = {Engine, NewEngineState},
         compactor_pid = Pid
     }}.
 
-
 finish_compaction(Db, CompactInfo) ->
     #db{
         engine = {Engine, St},
         name = DbName,
         options = Options
     } = Db,
-    NewDb = case Engine:finish_compaction(St, DbName, Options, CompactInfo) of
-        {ok, NewState, undefined} ->
-            couch_event:notify(DbName, compacted),
-            Db#db{
-                engine = {Engine, NewState},
-                compactor_pid = nil
-            };
-        {ok, NewState, CompactorPid} when is_pid(CompactorPid) ->
-            Db#db{
-                engine = {Engine, NewState},
-                compactor_pid = CompactorPid
-            }
-    end,
+    NewDb =
+        case Engine:finish_compaction(St, DbName, Options, CompactInfo) of
+            {ok, NewState, undefined} ->
+                couch_event:notify(DbName, compacted),
+                Db#db{
+                    engine = {Engine, NewState},
+                    compactor_pid = nil
+                };
+            {ok, NewState, CompactorPid} when is_pid(CompactorPid) ->
+                Db#db{
+                    engine = {Engine, NewState},
+                    compactor_pid = CompactorPid
+                }
+        end,
     ok = couch_server:db_updated(NewDb),
     {ok, NewDb}.
 
-
 trigger_on_compact(DbName) ->
     {ok, DDocs} = get_ddocs(DbName),
     couch_db_plugin:on_compact(DbName, DDocs).
 
-
 get_ddocs(<<"shards/", _/binary>> = DbName) ->
     {_, Ref} = spawn_monitor(fun() ->
         exit(fabric:design_docs(mem3:dbname(DbName)))
     end),
     receive
         {'DOWN', Ref, _, _, {ok, JsonDDocs}} ->
-            {ok, lists:map(fun(JsonDDoc) ->
-                couch_doc:from_json_obj(JsonDDoc)
-            end, JsonDDocs)};
+            {ok,
+                lists:map(
+                    fun(JsonDDoc) ->
+                        couch_doc:from_json_obj(JsonDDoc)
+                    end,
+                    JsonDDocs
+                )};
         {'DOWN', Ref, _, _, Else} ->
             Else
     end;
