@@ -745,8 +745,8 @@ rev_etag({Start, DiskRev}) ->
     <<$", Rev/binary, $">>.
 
 make_etag(Term) ->
-    <<SigInt:128/integer>> = couch_hash:md5_hash(term_to_binary(Term)),
-    iolist_to_binary([$", io_lib:format("~.36B", [SigInt]), $"]).
+    <<SigInt:128/integer>> = exxhash:xxhash128(?term_to_bin(Term)),
+    list_to_binary(io_lib:format("\"~.36B\"", [SigInt])).
 
 etag_match(Req, CurrentEtag) when is_binary(CurrentEtag) ->
     etag_match(Req, binary_to_list(CurrentEtag));
@@ -1202,11 +1202,16 @@ negotiate_content_type(_Req) ->
     end.
 
 server_header() ->
-    [
-        {"Server",
-            "CouchDB/" ++ couch_server:get_version() ++
-                " (Erlang OTP/" ++ erlang:system_info(otp_release) ++ ")"}
-    ].
+    case chttpd_util:get_chttpd_config_boolean("server_header_versions", true) of
+        false ->
+            [{"Server", "CouchDB"}];
+        true ->
+            [
+                {"Server",
+                    "CouchDB/" ++ couch_server:get_version() ++
+                        " (Erlang OTP/" ++ erlang:system_info(otp_release) ++ ")"}
+            ]
+    end.
 
 -record(mp, {boundary, buffer, data_fun, callback}).
 
