@@ -15,7 +15,6 @@
 -include_lib("couch/include/couch_eunit.hrl").
 -include_lib("couch/include/couch_db.hrl").
 
-
 setup() ->
     mock(couch_log),
     mock(config),
@@ -38,27 +37,32 @@ mock(couch_log) ->
     ok;
 mock(config) ->
     meck:new(config, [passthrough]),
-    meck:expect(config, get_integer,
-        fun("couchdb", "max_document_size", 8000000) -> 1024 end),
+    meck:expect(
+        config,
+        get_integer,
+        fun("couchdb", "max_document_size", 8000000) -> 1024 end
+    ),
     meck:expect(config, get, fun(_, _) -> undefined end),
     meck:expect(config, get, fun(_, _, Default) -> Default end),
     ok.
 
-
 json_doc_test_() ->
     {
         setup,
-        fun setup/0, fun teardown/1,
+        fun setup/0,
+        fun teardown/1,
         fun(_) ->
-            [{"Document from JSON", [
-                from_json_with_dbname_error_cases(),
-                from_json_with_db_name_success_cases(),
-                from_json_success_cases(),
-                from_json_error_cases()
-             ]},
-             {"Document to JSON", [
-                 to_json_success_cases()
-             ]}]
+            [
+                {"Document from JSON", [
+                    from_json_with_dbname_error_cases(),
+                    from_json_with_db_name_success_cases(),
+                    from_json_success_cases(),
+                    from_json_error_cases()
+                ]},
+                {"Document to JSON", [
+                    to_json_success_cases()
+                ]}
+            ]
         end
     }.
 
@@ -95,35 +99,42 @@ from_json_success_cases() ->
             "Non underscore prefixed fields stored in body."
         },
         {
-            {[{<<"_attachments">>, {[
-                {<<"my_attachment.fu">>, {[
-                    {<<"stub">>, true},
-                    {<<"content_type">>, <<"application/awesome">>},
-                    {<<"length">>, 45}
-                ]}},
-                {<<"noahs_private_key.gpg">>, {[
-                    {<<"data">>, <<"SSBoYXZlIGEgcGV0IGZpc2gh">>},
-                    {<<"content_type">>, <<"application/pgp-signature">>}
-                ]}}
-            ]}}]},
-            #doc{atts = [
-                couch_att:new([
-                    {name, <<"my_attachment.fu">>},
-                    {data, stub},
-                    {type, <<"application/awesome">>},
-                    {att_len, 45},
-                    {disk_len, 45},
-                    {revpos, undefined}
-                ]),
-                couch_att:new([
-                    {name, <<"noahs_private_key.gpg">>},
-                    {data, <<"I have a pet fish!">>},
-                    {type, <<"application/pgp-signature">>},
-                    {att_len, 18},
-                    {disk_len, 18},
-                    {revpos, 0}
-                ])
+            {[
+                {<<"_attachments">>,
+                    {[
+                        {<<"my_attachment.fu">>,
+                            {[
+                                {<<"stub">>, true},
+                                {<<"content_type">>, <<"application/awesome">>},
+                                {<<"length">>, 45}
+                            ]}},
+                        {<<"noahs_private_key.gpg">>,
+                            {[
+                                {<<"data">>, <<"SSBoYXZlIGEgcGV0IGZpc2gh">>},
+                                {<<"content_type">>, <<"application/pgp-signature">>}
+                            ]}}
+                    ]}}
             ]},
+            #doc{
+                atts = [
+                    couch_att:new([
+                        {name, <<"my_attachment.fu">>},
+                        {data, stub},
+                        {type, <<"application/awesome">>},
+                        {att_len, 45},
+                        {disk_len, 45},
+                        {revpos, undefined}
+                    ]),
+                    couch_att:new([
+                        {name, <<"noahs_private_key.gpg">>},
+                        {data, <<"I have a pet fish!">>},
+                        {type, <<"application/pgp-signature">>},
+                        {att_len, 18},
+                        {disk_len, 18},
+                        {revpos, 0}
+                    ])
+                ]
+            },
             "Attachments are parsed correctly."
         },
         {
@@ -138,11 +149,13 @@ from_json_success_cases() ->
         },
         {
             {[
-                 {<<"_revisions">>,
-                  {[{<<"start">>, 4},
-                    {<<"ids">>, [<<"foo1">>, <<"phi3">>, <<"omega">>]}]}},
-                 {<<"_rev">>, <<"6-something">>}
-             ]},
+                {<<"_revisions">>,
+                    {[
+                        {<<"start">>, 4},
+                        {<<"ids">>, [<<"foo1">>, <<"phi3">>, <<"omega">>]}
+                    ]}},
+                {<<"_rev">>, <<"6-something">>}
+            ]},
             #doc{revs = {4, [<<"foo1">>, <<"phi3">>, <<"omega">>]}},
             "_revisions attribute are preferred to _rev."
         },
@@ -171,7 +184,8 @@ from_json_success_cases() ->
         fun({EJson, Expect, Msg}) ->
             {Msg, ?_assertMatch(Expect, couch_doc:from_json_obj_validate(EJson))}
         end,
-        Cases).
+        Cases
+    ).
 
 from_json_with_db_name_success_cases() ->
     Cases = [
@@ -210,7 +224,8 @@ from_json_with_db_name_success_cases() ->
         fun({EJson, DbName, Expect, Msg}) ->
             {Msg, ?_assertMatch(Expect, couch_doc:from_json_obj_validate(EJson, DbName))}
         end,
-        Cases).
+        Cases
+    ).
 
 from_json_error_cases() ->
     Cases = [
@@ -236,8 +251,7 @@ from_json_error_cases() ->
         },
         {
             {[{<<"_id">>, <<"_random">>}]},
-            {illegal_docid,
-             <<"Only reserved document ids may start with underscore.">>},
+            {illegal_docid, <<"Only reserved document ids may start with underscore.">>},
             "Disallow arbitrary underscore prefixed docids."
         },
         {
@@ -270,8 +284,13 @@ from_json_error_cases() ->
             "Revision ids must be strings."
         },
         {
-            {[{<<"_revisions">>, {[{<<"start">>, 0},
-                {<<"ids">>, [<<"xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx">>]}]}}]},
+            {[
+                {<<"_revisions">>,
+                    {[
+                        {<<"start">>, 0},
+                        {<<"ids">>, [<<"xxxxxxxxxxxxxxxxxxxxxxxxxxxxxxxx">>]}
+                    ]}}
+            ]},
             {doc_validation, "RevId isn't a valid hexadecimal"},
             "Revision ids must be a valid hex."
         },
@@ -284,7 +303,7 @@ from_json_error_cases() ->
             fun() ->
                 {[
                     {<<"_id">>, <<"large_doc">>},
-                    {<<"x">> , << <<"x">> || _ <- lists:seq(1,1025) >>}
+                    {<<"x">>, <<<<"x">> || _ <- lists:seq(1, 1025)>>}
                 ]}
             end,
             {request_entity_too_large, <<"large_doc">>},
@@ -292,39 +311,36 @@ from_json_error_cases() ->
         }
     ],
 
-    lists:map(fun
-        ({Fun, Expect, Msg}) when is_function(Fun, 0) ->
-            {Msg,
-            ?_assertThrow(Expect, couch_doc:from_json_obj_validate(Fun()))};
-        ({EJson, Expect, Msg}) ->
-            {Msg,
-            ?_assertThrow(Expect, couch_doc:from_json_obj_validate(EJson))};
-        ({EJson, Msg}) ->
-            {Msg,
-            ?_assertThrow(_, couch_doc:from_json_obj_validate(EJson))}
-    end, Cases).
+    lists:map(
+        fun
+            ({Fun, Expect, Msg}) when is_function(Fun, 0) ->
+                {Msg, ?_assertThrow(Expect, couch_doc:from_json_obj_validate(Fun()))};
+            ({EJson, Expect, Msg}) ->
+                {Msg, ?_assertThrow(Expect, couch_doc:from_json_obj_validate(EJson))};
+            ({EJson, Msg}) ->
+                {Msg, ?_assertThrow(_, couch_doc:from_json_obj_validate(EJson))}
+        end,
+        Cases
+    ).
 
 from_json_with_dbname_error_cases() ->
     Cases = [
         {
             {[{<<"_id">>, <<"_random">>}]},
             <<"_dbs">>,
-            {illegal_docid,
-             <<"Only reserved document ids may start with underscore.">>},
+            {illegal_docid, <<"Only reserved document ids may start with underscore.">>},
             "Disallow non-system-DB underscore prefixed docids in _dbs database."
         },
         {
             {[{<<"_id">>, <<"_random">>}]},
             <<"foobar">>,
-            {illegal_docid,
-             <<"Only reserved document ids may start with underscore.">>},
+            {illegal_docid, <<"Only reserved document ids may start with underscore.">>},
             "Disallow arbitrary underscore prefixed docids in regular database."
         },
         {
             {[{<<"_id">>, <<"_users">>}]},
             <<"foobar">>,
-            {illegal_docid,
-             <<"Only reserved document ids may start with underscore.">>},
+            {illegal_docid, <<"Only reserved document ids may start with underscore.">>},
             "Disallow system-DB docid _users in regular database."
         }
     ],
@@ -334,7 +350,8 @@ from_json_with_dbname_error_cases() ->
             Error = (catch couch_doc:from_json_obj_validate(EJson, DbName)),
             {Msg, ?_assertMatch(Expect, Error)}
         end,
-        Cases).
+        Cases
+    ).
 
 to_json_success_cases() ->
     Cases = [
@@ -357,13 +374,14 @@ to_json_success_cases() ->
             [revs],
             #doc{revs = {5, [<<"first">>, <<"second">>]}},
             {[
-                 {<<"_id">>, <<>>},
-                 {<<"_rev">>, <<"5-first">>},
-                 {<<"_revisions">>, {[
-                     {<<"start">>, 5},
-                     {<<"ids">>, [<<"first">>, <<"second">>]}
-                 ]}}
-             ]},
+                {<<"_id">>, <<>>},
+                {<<"_rev">>, <<"5-first">>},
+                {<<"_revisions">>,
+                    {[
+                        {<<"start">>, 5},
+                        {<<"ids">>, [<<"first">>, <<"second">>]}
+                    ]}}
+            ]},
             "_revisions include with revs option"
         },
         {
@@ -377,16 +395,18 @@ to_json_success_cases() ->
             "Deleted docs no longer drop body members."
         },
         {
-            #doc{meta = [
-                {revs_info, 4, [{<<"fin">>, deleted}, {<<"zim">>, missing}]}
-            ]},
+            #doc{
+                meta = [
+                    {revs_info, 4, [{<<"fin">>, deleted}, {<<"zim">>, missing}]}
+                ]
+            },
             {[
-                 {<<"_id">>, <<>>},
-                 {<<"_revs_info">>, [
-                     {[{<<"rev">>, <<"4-fin">>}, {<<"status">>, <<"deleted">>}]},
-                     {[{<<"rev">>, <<"3-zim">>}, {<<"status">>, <<"missing">>}]}
-                 ]}
-             ]},
+                {<<"_id">>, <<>>},
+                {<<"_revs_info">>, [
+                    {[{<<"rev">>, <<"4-fin">>}, {<<"status">>, <<"deleted">>}]},
+                    {[{<<"rev">>, <<"3-zim">>}, {<<"status">>, <<"missing">>}]}
+                ]}
+            ]},
             "_revs_info field is added correctly."
         },
         {
@@ -405,89 +425,102 @@ to_json_success_cases() ->
         {
             #doc{meta = [{deleted_conflicts, [{10923, <<"big_cowboy_hat">>}]}]},
             {[
-                 {<<"_id">>, <<>>},
-                 {<<"_deleted_conflicts">>, [<<"10923-big_cowboy_hat">>]}
-             ]},
+                {<<"_id">>, <<>>},
+                {<<"_deleted_conflicts">>, [<<"10923-big_cowboy_hat">>]}
+            ]},
             "_deleted_conflicsts is added as an array of strings."
         },
         {
-            #doc{atts = [
-                couch_att:new([
-                    {name, <<"big.xml">>},
-                    {type, <<"xml/sucks">>},
-                    {data, fun() -> ok end},
-                    {revpos, 1},
-                    {att_len, 400},
-                    {disk_len, 400}
-                ]),
-                couch_att:new([
-                    {name, <<"fast.json">>},
-                    {type, <<"json/ftw">>},
-                    {data, <<"{\"so\": \"there!\"}">>},
-                    {revpos, 1},
-                    {att_len, 16},
-                    {disk_len, 16}
-                ])
-            ]},
+            #doc{
+                atts = [
+                    couch_att:new([
+                        {name, <<"big.xml">>},
+                        {type, <<"xml/sucks">>},
+                        {data, fun() -> ok end},
+                        {revpos, 1},
+                        {att_len, 400},
+                        {disk_len, 400}
+                    ]),
+                    couch_att:new([
+                        {name, <<"fast.json">>},
+                        {type, <<"json/ftw">>},
+                        {data, <<"{\"so\": \"there!\"}">>},
+                        {revpos, 1},
+                        {att_len, 16},
+                        {disk_len, 16}
+                    ])
+                ]
+            },
             {[
-                 {<<"_id">>, <<>>},
-                 {<<"_attachments">>, {[
-                       {<<"big.xml">>, {[
-                           {<<"content_type">>, <<"xml/sucks">>},
-                           {<<"revpos">>, 1},
-                           {<<"length">>, 400},
-                           {<<"stub">>, true}
-                       ]}},
-                       {<<"fast.json">>, {[
-                           {<<"content_type">>, <<"json/ftw">>},
-                           {<<"revpos">>, 1},
-                           {<<"length">>, 16},
-                           {<<"stub">>, true}
-                       ]}}
-                ]}}
+                {<<"_id">>, <<>>},
+                {<<"_attachments">>,
+                    {[
+                        {<<"big.xml">>,
+                            {[
+                                {<<"content_type">>, <<"xml/sucks">>},
+                                {<<"revpos">>, 1},
+                                {<<"length">>, 400},
+                                {<<"stub">>, true}
+                            ]}},
+                        {<<"fast.json">>,
+                            {[
+                                {<<"content_type">>, <<"json/ftw">>},
+                                {<<"revpos">>, 1},
+                                {<<"length">>, 16},
+                                {<<"stub">>, true}
+                            ]}}
+                    ]}}
             ]},
             "Attachments attached as stubs only include a length."
         },
         {
             [attachments],
-            #doc{atts = [
-                couch_att:new([
-                    {name, <<"stuff.txt">>},
-                    {type, <<"text/plain">>},
-                    {data, fun() -> <<"diet pepsi">> end},
-                    {revpos, 1},
-                    {att_len, 10},
-                    {disk_len, 10}
-                ]),
-                couch_att:new([
-                    {name, <<"food.now">>},
-                    {type, <<"application/food">>},
-                    {revpos, 1},
-                    {data, <<"sammich">>}
-                ])
-            ]},
+            #doc{
+                atts = [
+                    couch_att:new([
+                        {name, <<"stuff.txt">>},
+                        {type, <<"text/plain">>},
+                        {data, fun() -> <<"diet pepsi">> end},
+                        {revpos, 1},
+                        {att_len, 10},
+                        {disk_len, 10}
+                    ]),
+                    couch_att:new([
+                        {name, <<"food.now">>},
+                        {type, <<"application/food">>},
+                        {revpos, 1},
+                        {data, <<"sammich">>}
+                    ])
+                ]
+            },
             {[
                 {<<"_id">>, <<>>},
-                {<<"_attachments">>, {[
-                   {<<"stuff.txt">>, {[
-                       {<<"content_type">>, <<"text/plain">>},
-                       {<<"revpos">>, 1},
-                       {<<"data">>, <<"ZGlldCBwZXBzaQ==">>}
-                   ]}},
-                   {<<"food.now">>, {[
-                       {<<"content_type">>, <<"application/food">>},
-                       {<<"revpos">>, 1},
-                       {<<"data">>, <<"c2FtbWljaA==">>}
-                   ]}}
-                ]}}
+                {<<"_attachments">>,
+                    {[
+                        {<<"stuff.txt">>,
+                            {[
+                                {<<"content_type">>, <<"text/plain">>},
+                                {<<"revpos">>, 1},
+                                {<<"data">>, <<"ZGlldCBwZXBzaQ==">>}
+                            ]}},
+                        {<<"food.now">>,
+                            {[
+                                {<<"content_type">>, <<"application/food">>},
+                                {<<"revpos">>, 1},
+                                {<<"data">>, <<"c2FtbWljaA==">>}
+                            ]}}
+                    ]}}
             ]},
             "Attachments included inline with attachments option."
         }
     ],
 
-    lists:map(fun
-        ({Doc, EJson, Msg}) ->
-            {Msg, ?_assertMatch(EJson, couch_doc:to_json_obj(Doc, []))};
-        ({Options, Doc, EJson, Msg}) ->
-            {Msg, ?_assertMatch(EJson, couch_doc:to_json_obj(Doc, Options))}
-    end, Cases).
+    lists:map(
+        fun
+            ({Doc, EJson, Msg}) ->
+                {Msg, ?_assertMatch(EJson, couch_doc:to_json_obj(Doc, []))};
+            ({Options, Doc, EJson, Msg}) ->
+                {Msg, ?_assertMatch(EJson, couch_doc:to_json_obj(Doc, Options))}
+        end,
+        Cases
+    ).
