@@ -15,15 +15,13 @@
 
 -compile(tuple_calls).
 
--vsn(3).
-
 %% API
 -export([start_link/1, stop/1, get_state/2, get_info/1]).
 -export([trigger_update/2]).
 -export([compact/1, compact/2, get_compactor_pid/1]).
 
 %% gen_server callbacks
--export([init/1, terminate/2, code_change/3]).
+-export([init/1, terminate/2]).
 -export([handle_call/3, handle_cast/2, handle_info/2]).
 
 -include_lib("couch/include/couch_db.hrl").
@@ -366,9 +364,6 @@ handle_info({'DOWN', _, _, _Pid, _}, #st{mod = Mod, idx_state = IdxState} = Stat
     catch send_all(State#st.waiters, shutdown),
     {stop, normal, State#st{waiters = []}}.
 
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 maybe_restart_updater(#st{waiters = []}) ->
     ok;
 maybe_restart_updater(#st{idx_state = IdxState} = State) ->
