@@ -58,6 +58,7 @@
 replicate(PostBody, Ctx) ->
     {ok, Rep0} = couch_replicator_parse:parse_rep_doc(PostBody, Ctx),
     Rep = Rep0#rep{start_time = os:timestamp()},
+    ok = couch_replicator_utils:valid_endpoint_protocols_log(Rep),
     #rep{id = RepId, options = Options, user_ctx = UserCtx} = Rep,
     case get_value(cancel, Options, false) of
         true ->
@@ -178,19 +179,15 @@ restart_job(JobId0) ->
 -spec active_doc(binary(), binary()) -> {ok, {[_]}} | {error, not_found}.
 active_doc(DbName, DocId) ->
     try
-        Shards = mem3:shards(DbName),
-        Live = [node() | nodes()],
-        Nodes = lists:usort([
-            N
-         || #shard{node = N} <- Shards,
-            lists:member(N, Live)
-        ]),
-        Owner = mem3:owner(DbName, DocId, Nodes),
+        Owner = couch_replicator_utils:owner(DbName, DocId),
         case active_doc_rpc(DbName, DocId, [Owner]) of
             {ok, DocInfo} ->
                 {ok, DocInfo};
             {error, not_found} ->
-                active_doc_rpc(DbName, DocId, Nodes -- [Owner])
+                Shards = mem3:shards(DbName, DocId),
+                Live = [node() | nodes()] -- [Owner],
+                Nodes = [N || #shard{node = N} <- Shards, lists:member(N, Live)],
+                active_doc_rpc(DbName, DocId, Nodes)
         end
     catch
         % Might be a local database
