@@ -17,8 +17,10 @@
     unwrap/1
 ]).
 
+-include_lib("couch/include/couch_db.hrl").
+
 wrap(Value) ->
-    {?MODULE, term_to_binary(Value)}.
+    {?MODULE, ?term_to_bin(Value)}.
 
 unwrap({?MODULE, Bin}) when is_binary(Bin) ->
     binary_to_term(Bin).
