@@ -47,7 +47,7 @@
 
 -define(INDENT, 4).
 
--spec to_algebra(erlfmt_parse:abstract_form()) -> erlfmt_algebra:doc().
+-spec to_algebra(erlfmt_parse:any_node()) -> erlfmt_algebra:doc().
 to_algebra({shebang, Meta, String}) ->
     Doc = string(String),
     combine_comments(Meta, Doc);
@@ -55,7 +55,7 @@ to_algebra({function, Meta, Clauses}) ->
     Doc = clauses_to_algebra(Clauses),
     combine_comments_with_dot(Meta, Doc);
 to_algebra({attribute, Meta, Name, no_parens}) ->
-    Doc = concat(<<"-">>, expr_to_algebra(Name)),
+    Doc = concat(<<"-">>, attribute_to_algebra(Name)),
     combine_comments_with_dot(Meta, Doc);
 to_algebra({attribute, Meta, {atom, _, define}, [Define, empty]}) ->
     Doc = concat(<<"-define(">>, expr_to_algebra(Define), <<",)">>),
@@ -94,7 +94,7 @@ to_algebra({attribute, Meta, {atom, _, record}, [Name, {tuple, TMeta, Values} =
             combine_comments_with_dot(Meta, Doc)
     end;
 to_algebra({attribute, Meta, Name, Values}) ->
-    Doc = concat(<<"-">>, expr_to_algebra(Name), call(Meta, Values, <<"(">>, <<")">>)),
+    Doc = concat(<<"-">>, attribute_to_algebra(Name), call(Meta, Values, <<"(">>, <<")">>)),
     combine_comments_with_dot(Meta, Doc);
 to_algebra(Expr) ->
     Meta = element(2, Expr),
@@ -106,6 +106,9 @@ to_algebra(Expr) ->
             combine_comments(Meta, Doc)
     end.
 
+attribute_to_algebra({atom, Meta, 'else'}) -> string(erlfmt_scan:get_anno(text, Meta));
+attribute_to_algebra(Other) -> expr_to_algebra(Other).
+
 expr_to_algebra(Expr) when is_tuple(Expr) ->
     Meta = element(2, Expr),
     Doc = do_expr_to_algebra(Expr),
@@ -117,6 +120,10 @@ do_expr_to_algebra({string, Meta, _Value}) ->
     string_to_algebra(erlfmt_scan:get_anno(text, Meta));
 do_expr_to_algebra({char, #{text := "$ "}, $\s}) ->
     <<"$\\s">>;
+do_expr_to_algebra({atom, _, 'maybe'}) ->
+    string(<<"'maybe'">>);
+do_expr_to_algebra({atom, _, 'else'}) ->
+    string(<<"'else'">>);
 do_expr_to_algebra({Atomic, Meta, _Value}) when ?IS_ATOMIC(Atomic) ->
     string(erlfmt_scan:get_anno(text, Meta));
 do_expr_to_algebra({pid, _Meta, Dotted}) ->
@@ -169,6 +176,8 @@ do_expr_to_algebra({record_name, Meta, Name}) ->
     record_name_to_algebra(Meta, Name);
 do_expr_to_algebra({lc, _Meta, Expr, LcExprs}) ->
     comprehension_to_algebra(Expr, LcExprs, <<"[">>, <<"]">>);
+do_expr_to_algebra({mc, _Meta, Expr, LcExprs}) ->
+    comprehension_to_algebra(Expr, LcExprs, <<"#{">>, <<"}">>);
 do_expr_to_algebra({bc, _Meta, Expr, LcExprs}) ->
     comprehension_to_algebra(Expr, LcExprs, <<"<<">>, <<">>">>);
 do_expr_to_algebra({generate, _Meta, Left, Right}) ->
@@ -194,6 +203,18 @@ do_expr_to_algebra({args, Meta, Values}) ->
 do_expr_to_algebra({'case', _Meta, Expr, Clauses}) ->
     Prefix = surround(<<"case">>, <<" ">>, expr_to_algebra(Expr), <<" ">>, <<"of">>),
     surround_block(Prefix, clauses_to_algebra(Clauses), <<"end">>);
+do_expr_to_algebra({'maybe', _Meta, MaybeExpressions}) ->
+    surround_block(<<"maybe">>, maybe_expressions_to_algebra(MaybeExpressions), <<"end">>);
+do_expr_to_algebra({'maybe', _Meta, MaybeExpressions, Else}) ->
+    ElseD = expr_to_algebra(Else),
+    surround_block(
+        <<"maybe">>, maybe_expressions_to_algebra(MaybeExpressions), line(ElseD, <<"end">>)
+    );
+do_expr_to_algebra({else_clause, _Meta, Clauses}) ->
+    concat(
+        force_breaks(),
+        group(concat(<<"else">>, nest(concat(line(), clauses_to_algebra(Clauses)), ?INDENT)))
+    );
 do_expr_to_algebra({'receive', _Meta, Clauses}) ->
     surround_block(<<"receive">>, expr_to_algebra(Clauses), <<"end">>);
 do_expr_to_algebra({'receive', _Meta, empty, After}) ->
@@ -503,7 +524,7 @@ surround_container(#break{inner = ForceInner, outer = ForceOuter}, Left, Doc, Ri
 
 %% last_fits_fun returns a fun similar to next_break_fits/2
 %% that takes into account the desired fits behaviour.
--spec last_fits_fun(last_normal | last_fits, [erlfmt_parse:abstract_form()]) ->
+-spec last_fits_fun(last_normal | last_fits, [erlfmt_parse:any_node()]) ->
     fun((erlfmt_algebra:doc(), disabled | enabled) -> erlfmt_algebra:doc()).
 last_fits_fun(last_fits, Values) when Values =/= [] ->
     case is_next_break_fits(lists:last(Values)) of
@@ -524,7 +545,7 @@ has_trailing_comments(Values) ->
             PostComments =/= []
     end.
 
--spec has_opening_line_break(erlfmt_scan:anno(), [erlfmt_parse:abstract_form()]) -> boolean().
+-spec has_opening_line_break(erlfmt_scan:anno(), [erlfmt_parse:any_node()]) -> boolean().
 has_opening_line_break(_Meta, []) ->
     false;
 has_opening_line_break(Meta, [HeadValue | _]) ->
@@ -541,7 +562,7 @@ has_any_break_between(_) ->
 break_fun(flex_break) -> fun erlfmt_algebra:flex_break/2;
 break_fun(_) -> fun erlfmt_algebra:break/2.
 
--type value_doc_pair() :: {erlfmt_parse:abstract_form(), erlfmt_algebra:doc()}.
+-type value_doc_pair() :: {erlfmt_parse:any_node(), erlfmt_algebra:doc()}.
 
 map_inner_values(_LastFitsFun, []) ->
     [];
@@ -761,6 +782,11 @@ clause_head_to_algebra({op, Meta, Op, Left, Right}) ->
 clause_head_to_algebra(Head) ->
     expr_to_algebra(Head).
 
+maybe_expressions_to_algebra([Expression]) ->
+    expr_to_algebra(Expression);
+maybe_expressions_to_algebra([Expression1 | Rest]) ->
+    line(concat(expr_to_algebra(Expression1), <<",">>), maybe_expressions_to_algebra(Rest)).
+
 spec_clause_gaurds_to_algebra(Expr) ->
     Meta = element(2, Expr),
     Doc =
