@@ -31,6 +31,7 @@
     get_all_security/1, get_all_security/2,
     get_purge_infos_limit/1,
     set_purge_infos_limit/3,
+    get_purged_infos/1,
     compact/1, compact/2,
     get_partition_info/2
 ]).
@@ -83,19 +84,9 @@ all_dbs() ->
 %% @doc returns a list of all database names
 -spec all_dbs(Prefix :: iodata()) -> {ok, [binary()]}.
 all_dbs(Prefix) when is_binary(Prefix) ->
-    Length = byte_size(Prefix),
-    MatchingDbs = mem3:fold_shards(
-        fun(#shard{dbname = DbName}, Acc) ->
-            case DbName of
-                <<Prefix:Length/binary, _/binary>> ->
-                    [DbName | Acc];
-                _ ->
-                    Acc
-            end
-        end,
-        []
-    ),
-    {ok, lists:usort(MatchingDbs)};
+    FoldFun = fun(DbName, Acc) -> [DbName | Acc] end,
+    DbNames = mem3:fold_dbs(Prefix, FoldFun, []),
+    {ok, lists:reverse(DbNames)};
 %% @equiv all_dbs(list_to_binary(Prefix))
 all_dbs(Prefix) when is_list(Prefix) ->
     all_dbs(list_to_binary(Prefix)).
@@ -211,6 +202,12 @@ get_purge_infos_limit(DbName) ->
         catch couch_db:close(Db)
     end.
 
+%% @doc returns purged requests history for the given database
+-spec get_purged_infos(dbname()) ->
+    {ok, [{purged_infos, json_obj()}]} | {error, Reason :: term()}.
+get_purged_infos(Db) ->
+    fabric_db_purged_infos:go(dbname(Db)).
+
 get_security(DbName) ->
     get_security(DbName, [?ADMIN_CTX]).
 
@@ -404,9 +401,7 @@ all_docs(DbName, Callback, Acc, QueryArgs) ->
 
 %% @doc retrieves all docs. Additional query parameters, such as `limit',
 %%      `start_key' and `end_key', `descending', and `include_docs', can
-%%      also be passed to further constrain the query. See <a href=
-%%      "http://wiki.apache.org/couchdb/HTTP_Document_API#All_Documents">
-%%      all_docs</a> for details
+%%      also be passed to further constrain the query.
 -spec all_docs(
     dbname(),
     [{atom(), any()}],
@@ -437,7 +432,8 @@ changes(DbName, Callback, Acc0, Options) ->
 
 %% @equiv query_view(DbName, DesignName, ViewName, #mrargs{})
 query_view(DbName, DesignName, ViewName) ->
-    query_view(DbName, DesignName, ViewName, #mrargs{}).
+    QueryArgs = #mrargs{extra = [{view_row_map, true}]},
+    query_view(DbName, DesignName, ViewName, QueryArgs).
 
 %% @equiv query_view(DbName, DesignName,
 %%                     ViewName, fun default_callback/2, [], QueryArgs)
@@ -451,9 +447,6 @@ query_view(DbName, DDoc, ViewName, Callback, Acc, QueryArgs) ->
     query_view(DbName, [], DDoc, ViewName, Callback, Acc, QueryArgs).
 
 %% @doc execute a given view.
-%%      There are many additional query args that can be passed to a view,
-%%      see <a href="http://wiki.apache.org/couchdb/HTTP_view_API#Querying_Options">
-%%      query args</a> for details.
 -spec query_view(
     dbname(),
     [{atom(), any()}] | [],
@@ -543,10 +536,11 @@ end_changes() ->
 %% @doc retrieve all the design docs from a database
 -spec design_docs(dbname()) -> {ok, [json_obj()]} | {error, Reason :: term()}.
 design_docs(DbName) ->
+    Extra0 = [{view_row_map, true}],
     Extra =
         case get(io_priority) of
-            undefined -> [];
-            Else -> [{io_priority, Else}]
+            undefined -> Extra0;
+            Else -> [{io_priority, Else} | Extra0]
         end,
     QueryArgs0 = #mrargs{
         include_docs = true,
