@@ -87,7 +87,7 @@ go(DbName, "normal", Options, Callback, Acc0) ->
     end.
 
 keep_sending_changes(DbName, Args, Callback, Seqs, AccIn, Timeout, UpListen, T0) ->
-    #changes_args{limit = Limit, feed = Feed, heartbeat = Heartbeat} = Args,
+    #changes_args{limit = Limit, feed = Feed, heartbeat = Heartbeat, dir = Dir} = Args,
     {ok, Collector} = send_changes(DbName, Args, Callback, Seqs, AccIn, Timeout),
     #collector{
         limit = Limit2,
@@ -98,12 +98,15 @@ keep_sending_changes(DbName, Args, Callback, Seqs, AccIn, Timeout, UpListen, T0)
     LastSeq = pack_seqs(NewSeqs),
     MaintenanceMode = config:get("couchdb", "maintenance_mode"),
     NewEpoch = get_changes_epoch() > erlang:get(changes_epoch),
+    PendingCount = pending_count(Offset),
     if
+        Dir == rev, is_integer(PendingCount), PendingCount =< 0;
+        Limit2 =< 0, (Feed == "continuous" orelse Feed == "eventsource");
         Limit > Limit2, Feed == "longpoll";
         MaintenanceMode == "true";
         MaintenanceMode == "nolb";
         NewEpoch ->
-            Callback({stop, LastSeq, pending_count(Offset)}, AccOut0);
+            Callback({stop, LastSeq, PendingCount}, AccOut0);
         true ->
             {ok, AccOut} = Callback(waiting_for_updates, AccOut0),
             WaitForUpdate = wait_db_updated(UpListen),
@@ -117,22 +120,16 @@ keep_sending_changes(DbName, Args, Callback, Seqs, AccIn, Timeout, UpListen, T0)
                 end,
             case {Heartbeat, AccumulatedTime > Max, WaitForUpdate} of
                 {_, _, changes_feed_died} ->
-                    Callback({stop, LastSeq, pending_count(Offset)}, AccOut);
+                    Callback({stop, LastSeq, PendingCount}, AccOut);
                 {undefined, _, timeout} ->
-                    Callback({stop, LastSeq, pending_count(Offset)}, AccOut);
+                    Callback({stop, LastSeq, PendingCount}, AccOut);
                 {_, true, timeout} ->
-                    Callback({stop, LastSeq, pending_count(Offset)}, AccOut);
+                    Callback({stop, LastSeq, PendingCount}, AccOut);
                 _ ->
                     {ok, AccTimeout} = Callback(timeout, AccOut),
-                    ?MODULE:keep_sending_changes(
-                        DbName,
-                        Args#changes_args{limit = Limit2},
-                        Callback,
-                        LastSeq,
-                        AccTimeout,
-                        Timeout,
-                        UpListen,
-                        T0
+                    Args1 = Args#changes_args{limit = Limit2},
+                    keep_sending_changes(
+                        DbName, Args1, Callback, LastSeq, AccTimeout, Timeout, UpListen, T0
                     )
             end
     end.
@@ -201,27 +198,12 @@ send_changes(DbName, ChangesArgs, Callback, PackedSeqs, AccIn, Timeout) ->
                         end,
                         Workers
                     ),
-                    send_changes(
-                        DbName,
-                        Workers,
-                        LiveSeqs,
-                        ChangesArgs,
-                        Callback,
-                        AccIn,
-                        Timeout
-                    )
+                    send_changes(DbName, Workers, LiveSeqs, ChangesArgs, Callback, AccIn, Timeout)
                 after
                     fabric_streams:cleanup(Workers)
                 end;
-            {timeout, NewState} ->
-                DefunctWorkers = fabric_util:remove_done_workers(
-                    NewState#stream_acc.workers,
-                    waiting
-                ),
-                fabric_util:log_timeout(
-                    DefunctWorkers,
-                    "changes"
-                ),
+            {timeout, DefunctWorkers} ->
+                fabric_util:log_timeout(DefunctWorkers, "changes"),
                 throw({error, timeout});
             {error, Reason} ->
                 throw({error, Reason});
@@ -270,9 +252,6 @@ handle_message({rexi_DOWN, _, {_, NodeRef}, _}, _, State) ->
     fabric_view:check_down_shards(State, NodeRef);
 handle_message({rexi_EXIT, Reason}, Worker, State) ->
     fabric_view:handle_worker_exit(State, Worker, Reason);
-% Temporary upgrade clause - Case 24236
-handle_message({complete, Key}, Worker, State) when is_tuple(Key) ->
-    handle_message({complete, [{seq, Key}, {pending, 0}]}, Worker, State);
 handle_message({change, Props}, {Worker, _}, #collector{limit = 0} = State) ->
     O0 = State#collector.offset,
     O1 =
@@ -295,9 +274,7 @@ handle_message({complete, Props}, Worker, #collector{limit = 0} = State) ->
                 O0
         end,
     maybe_stop(State#collector{offset = O1});
-handle_message({no_pass, Props}, {Worker, From}, #collector{limit = 0} = State) when
-    is_list(Props)
-->
+handle_message({no_pass, [_ | _] = Props}, {Worker, From}, #collector{limit = 0} = State) ->
     #collector{counters = S0, offset = O0} = State,
     O1 =
         case fabric_dict:lookup_element(Worker, O0) of
@@ -309,16 +286,6 @@ handle_message({no_pass, Props}, {Worker, From}, #collector{limit = 0} = State)
     S1 = fabric_dict:store(Worker, couch_util:get_value(seq, Props), S0),
     rexi:stream_ack(From),
     maybe_stop(State#collector{counters = S1, offset = O1});
-handle_message(#change{} = Row, {Worker, From}, St) ->
-    Change =
-        {change, [
-            {seq, Row#change.key},
-            {id, Row#change.id},
-            {changes, Row#change.value},
-            {deleted, Row#change.deleted},
-            {doc, Row#change.doc}
-        ]},
-    handle_message(Change, {Worker, From}, St);
 handle_message({change, Props}, {Worker, From}, St) ->
     #collector{
         callback = Callback,
@@ -341,9 +308,6 @@ handle_message({change, Props}, {Worker, From}, St) ->
     {Go, Acc} = Callback(changes_row(Props2), AccIn),
     rexi:stream_ack(From),
     {Go, St#collector{counters = S1, offset = O1, limit = Limit - 1, user_acc = Acc}};
-%% upgrade clause
-handle_message({no_pass, Seq}, From, St) when is_integer(Seq) ->
-    handle_message({no_pass, [{seq, Seq}]}, From, St);
 handle_message({no_pass, Props}, {Worker, From}, St) ->
     Seq = couch_util:get_value(seq, Props),
     #collector{counters = S0} = St,
@@ -351,7 +315,7 @@ handle_message({no_pass, Props}, {Worker, From}, St) ->
     S1 = fabric_dict:store(Worker, Seq, S0),
     rexi:stream_ack(From),
     {ok, St#collector{counters = S1}};
-handle_message({complete, Props}, Worker, State) ->
+handle_message({complete, [_ | _] = Props}, Worker, State) ->
     Key = couch_util:get_value(seq, Props),
     #collector{
         counters = S0,
@@ -422,13 +386,28 @@ pending_count(Dict) ->
 
 pack_seqs(Workers) ->
     SeqList = [{N, R, S} || {#shard{node = N, range = R}, S} <- Workers],
-    SeqSum = lists:sum([seq(S) || {_, _, S} <- SeqList]),
-    Opaque = couch_util:encodeBase64Url(term_to_binary(SeqList, [compressed])),
+    SeqSum = lists:sum([fake_packed_seq(S) || {_, _, S} <- SeqList]),
+    Opaque = couch_util:encodeBase64Url(?term_to_bin(SeqList, [compressed])),
     ?l2b([integer_to_list(SeqSum), $-, Opaque]).
 
-seq({Seq, _Uuid, _Node}) -> Seq;
-seq({Seq, _Uuid}) -> Seq;
-seq(Seq) -> Seq.
+% Generate the sequence number used to build the emitted N-... prefix.
+%
+% The prefix is discarded when the sequence is decoded in the current CouchDB
+% version. It's mostly there as a visual heuristic about all the packed
+% sequences and to keep backwards compatibility with previous CouchDB versions.
+%
+% We handle a few backwards compatibility clauses, and also when we get a
+% sequence before a shard split. In that case, we fill in the missing ranges
+% with a special {split, OldNodeUUid} marker. However, when sequences are
+% emitted, that will make the N- prefix (SeqSum) bounce around from higher to
+% lower numbers if we leave it as is. To fix that, use 0 for that range,
+% assuming it will be full rewind. That way the N-... prefix is more likely to
+% be incrementing, which is what users would generally expect.
+%
+fake_packed_seq({Seq, {split, <<_/binary>>}, _Node}) when is_integer(Seq) -> 0;
+fake_packed_seq({Seq, _Uuid, _Node}) -> Seq;
+fake_packed_seq({Seq, _Uuid}) -> Seq;
+fake_packed_seq(Seq) -> Seq.
 
 unpack_seq_regex_match(Packed) ->
     Pattern = "^\"?([0-9]+-)?(?<opaque>.*?)\"?$",
@@ -1066,4 +1045,18 @@ find_replacement_sequence_test() ->
     ?assertEqual(0, find_replacement_sequence(Dead4, [0, 10])),
     ?assertEqual(0, find_replacement_sequence(Dead4, [0, 5])).
 
+pack_split_seq_test() ->
+    Shards = [{"n1", 0, 10}, {"n2", 11, ?RING_END}],
+    Workers = mk_workers(Shards, {42, {split, <<"abc1234">>}, 'node1@127.0.0.1'}),
+    PackedSeq = pack_seqs(Workers),
+    ?assertMatch(<<"0-", _/binary>>, PackedSeq),
+    DecodedSeq = decode_seq(PackedSeq),
+    ?assertEqual(
+        [
+            {n1, [0, 10], {42, {split, <<"abc1234">>}, 'node1@127.0.0.1'}},
+            {n2, [11, 4294967295], {42, {split, <<"abc1234">>}, 'node1@127.0.0.1'}}
+        ],
+        DecodedSeq
+    ).
+
 -endif.
