@@ -14,6 +14,7 @@
 
 -include_lib("couch/include/couch_db.hrl").
 -include_lib("couch/include/couch_eunit.hrl").
+-include_lib("couch_mrview/include/couch_mrview.hrl").
 
 cleanup_index_files_test_() ->
     {
@@ -238,3 +239,140 @@ delete_ddoc(DbName, DDocId) ->
     {ok, DDoc0} = fabric:open_doc(DbName, DDocId, [?ADMIN_CTX]),
     DDoc = DDoc0#doc{deleted = true, body = {[]}},
     fabric:update_doc(DbName, DDoc, [?ADMIN_CTX]).
+
+design_docs_test_() ->
+    {
+        foreach,
+        fun() -> ok end,
+        fun(_) -> meck:unload() end,
+        [
+            ?TDEF_FE(t_design_docs_configuration),
+            ?TDEF_FE(t_design_docs_configuration_io_priority)
+        ]
+    }.
+
+t_design_docs_configuration(_) ->
+    DbName = <<"db">>,
+    AdminCtx = [?ADMIN_CTX],
+    QueryArgs =
+        #mrargs{
+            include_docs = true,
+            extra = [{namespace, <<"_design">>}, {view_row_map, true}]
+        },
+    meck:expect(
+        fabric, all_docs, [DbName, AdminCtx, '_', [], QueryArgs], meck:val(all_docs_result)
+    ),
+    ?assertEqual(all_docs_result, fabric:design_docs(DbName)).
+
+t_design_docs_configuration_io_priority(_) ->
+    DbName = <<"db">>,
+    AdminCtx = [?ADMIN_CTX],
+    QueryArgs =
+        #mrargs{
+            include_docs = true,
+            extra = [{namespace, <<"_design">>}, {io_priority, io_priority}, {view_row_map, true}]
+        },
+    meck:expect(
+        fabric, all_docs, [DbName, AdminCtx, '_', [], QueryArgs], meck:val(all_docs_result)
+    ),
+    put(io_priority, io_priority),
+    ?assertEqual(all_docs_result, fabric:design_docs(DbName)).
+
+query_view_test_() ->
+    {
+        foreach,
+        fun setup/0,
+        fun teardown/1,
+        [
+            ?TDEF_FE(t_query_view_configuration)
+        ]
+    }.
+
+t_query_view_configuration({_Ctx, DbName}) ->
+    DDocName = <<"foo">>,
+    ViewName = <<"bar">>,
+    QueryArgs =
+        #mrargs{
+            view_type = map,
+            start_key_docid = <<>>,
+            end_key_docid = <<255>>,
+            extra = [{view_row_map, true}]
+        },
+    Options = [],
+    Accumulator = [],
+    Parameters = [DbName, Options, '_', ViewName, QueryArgs, '_', Accumulator, '_'],
+    meck:expect(fabric_view_map, go, Parameters, meck:val(fabric_view_map_results)),
+    ?assertEqual(fabric_view_map_results, fabric:query_view(DbName, DDocName, ViewName)).
+
+fabric_all_dbs_test_() ->
+    {
+        foreach,
+        fun setup_fabric/0,
+        fun teardown_fabric/1,
+        [
+            ?TDEF_FE(t_get_all_dbs),
+            ?TDEF_FE(t_prefix_works)
+        ]
+    }.
+
+t_get_all_dbs(_) ->
+    DbList = [<<"aaa">>, <<"a+b">>, <<"a$c">>, <<"aaa/bbb">>],
+    ?assertEqual(ok, create_dbs(DbList)),
+    ExpectList = lists:sort(DbList),
+    ?assertEqual({ok, ExpectList}, fabric:all_dbs()),
+    ?assertEqual(ok, delete_dbs(DbList)).
+
+t_prefix_works(_) ->
+    DbList = [
+        "aaa0",
+        "aaa+",
+        "aaa(",
+        "aa",
+        "a",
+        "aaaa",
+        "aaa/y",
+        "aaa/x",
+        "aaa/x$",
+        "aaa/x/z",
+        "aaa$"
+    ],
+    ?assertEqual(ok, create_dbs(DbList)),
+    AllExpect = lists:sort([list_to_binary(Db) || Db <- DbList]),
+    ?assertEqual({ok, AllExpect}, fabric:all_dbs()),
+    ?assertEqual({ok, AllExpect}, fabric:all_dbs(<<>>)),
+    ?assertEqual({ok, []}, fabric:all_dbs(<<"$">>)),
+    ?assertEqual({ok, []}, fabric:all_dbs(<<"b">>)),
+    ?assertEqual({ok, AllExpect}, fabric:all_dbs(<<"a">>)),
+    ?assertEqual({ok, AllExpect -- [<<"a">>, <<"aa">>]}, fabric:all_dbs(<<"aaa">>)),
+    ?assertEqual({ok, [<<"aaa0">>]}, fabric:all_dbs(<<"aaa0">>)),
+    ?assertEqual({ok, [<<"aaa+">>]}, fabric:all_dbs(<<"aaa+">>)),
+    ?assertEqual({ok, [<<"aaa(">>]}, fabric:all_dbs(<<"aaa(">>)),
+    ?assertEqual({ok, [<<"aaaa">>]}, fabric:all_dbs(<<"aaaa">>)),
+    ?assertEqual({ok, [<<"aaa/x$">>]}, fabric:all_dbs(<<"aaa/x$">>)),
+    ?assertEqual({ok, [<<"aaa/x">>, <<"aaa/x$">>, <<"aaa/x/z">>]}, fabric:all_dbs(<<"aaa/x">>)),
+    ?assertEqual({ok, [<<"aaa/x/z">>]}, fabric:all_dbs(<<"aaa/x/z">>)),
+    ?assertEqual({ok, [<<"aaa/x/z">>]}, fabric:all_dbs(<<"aaa/x/">>)),
+    TripleASlash = lists:sort([<<"aaa/x">>, <<"aaa/y">>, <<"aaa/x$">>, <<"aaa/x/z">>]),
+    ?assertEqual({ok, TripleASlash}, fabric:all_dbs(<<"aaa/">>)),
+    ?assertEqual(ok, delete_dbs(DbList)).
+
+create_dbs(DbList) ->
+    Fun = fun(DbName) -> ok = fabric:create_db(DbName) end,
+    lists:foreach(Fun, DbList).
+
+delete_dbs(DbList) ->
+    Fun = fun(DbName) -> ok = fabric:delete_db(DbName) end,
+    lists:foreach(Fun, DbList).
+
+setup_fabric() ->
+    Ctx = test_util:start_couch([fabric]),
+    ok = clear_shards_db(),
+    Ctx.
+
+teardown_fabric(Ctx) ->
+    ok = clear_shards_db(),
+    test_util:stop_couch(Ctx).
+
+clear_shards_db() ->
+    ShardsDb = ?l2b(config:get("mem3", "shards_db", "_dbs")),
+    couch_server:delete(ShardsDb, [?ADMIN_CTX]).
