@@ -10,6 +10,7 @@
 // License for the specific language governing permissions and limitations under
 // the License.
 
+import app from "../../../app";
 import ActionTypes from "./actiontypes";
 
 const initialState = {
@@ -25,16 +26,28 @@ const initialState = {
   uploadInProgress: false,
   uploadPercentage: 0,
 
-  docConflictCount: 0
+  docConflictCount: 0,
+  docEditorPreferences: loadDocEditorPreferences(),
 };
 
+function loadDocEditorPreferences() {
+  let savedPref = app.utils.localStorageGet('fauxton:doc_editor_preferences');
+  return {
+    // default values
+    wordWrapEnabled: false,
+    // merge saved preferences
+    ...(savedPref ? savedPref : {}),
+  };
+}
+
 export default function docEditor (state = initialState, action) {
   const { options, type } = action;
   switch (type) {
 
     case ActionTypes.RESET_DOC:
       return {
-        ...initialState
+        ...initialState,
+        docEditorPreferences: state.docEditorPreferences
       };
 
     case ActionTypes.DOC_LOADED:
@@ -131,6 +144,17 @@ export default function docEditor (state = initialState, action) {
         isSaving: false,
       };
 
+    case ActionTypes.TOGGLE_WRAP_LINE_OPTION:
+      const newPreferences = {
+        ...state.docEditorPreferences,
+        wordWrapEnabled: !(state.docEditorPreferences.wordWrapEnabled),
+      };
+      app.utils.localStorageSet('fauxton:doc_editor_preferences', newPreferences);
+      return {
+        ...state,
+        docEditorPreferences: newPreferences,
+      };
+
     default:
       return state;
   }
