@@ -37,8 +37,8 @@ module.exports = {
       .loginToGUI()
       .url(baseUrl + '/#/database/_replicator/_all_docs')
 
-      .clickWhenVisible('.faux-header__doc-header-dropdown-toggle')
-      .clickWhenVisible('.faux-header__doc-header-dropdown-itemwrapper .fonticon-trash')
+      .clickWhenVisible('#faux-header__doc-header-dropdown-toggle')
+      .clickWhenVisible('button.dropdown-item .fonticon-trash')
 
       .waitForElementVisible('.delete-db-modal', waitTime, false)
       .waitForElementVisible('.delete-db-modal input[type="text"]', waitTime, false)
@@ -55,8 +55,8 @@ module.exports = {
       .loginToGUI()
       .url(baseUrl + '/#/database/' + newDatabaseName + '/_all_docs')
 
-      .clickWhenVisible('.faux-header__doc-header-dropdown-toggle')
-      .clickWhenVisible('.faux-header__doc-header-dropdown-itemwrapper .fonticon-trash')
+      .clickWhenVisible('#faux-header__doc-header-dropdown-toggle')
+      .clickWhenVisible('button.dropdown-item .fonticon-trash')
 
       .waitForElementVisible('.delete-db-modal', waitTime, false)
       .waitForElementVisible('.delete-db-modal input[type="text"]', waitTime, false)
