@@ -14,9 +14,8 @@
 
 % gen_server boilerplate
 -behaviour(gen_server).
--vsn(1).
--export([init/1, terminate/2]).
--export([handle_call/3, handle_cast/2, handle_info/2, code_change/3]).
+-export([init/1]).
+-export([handle_call/3, handle_cast/2, handle_info/2]).
 
 % Public interface
 -export([start_link/0]).
@@ -25,7 +24,6 @@
 -export([add_all_shards/1]).
 -export([set_batch_size/1]).
 -export([set_delay/1]).
--export([set_limit/1]).
 -export([set_prune_interval/1]).
 
 % exports for spawn
@@ -44,7 +42,6 @@
 -record(state, {
     q = queue:new(),
     dbworker = nil,
-    limit = 20,
     delay = 5000,
     batch_size = 1,
     prune_interval = 60000,
@@ -103,12 +100,6 @@ set_batch_size(BS) when is_integer(BS), BS > 0 ->
 set_delay(Delay) when is_integer(Delay), Delay >= 0 ->
     gen_server:call(?MODULE, {set_delay, Delay}).
 
-%% @doc Changes the configured value for a limit.
-%% Returns previous value.
--spec set_limit(pos_integer()) -> pos_integer().
-set_limit(Limit) when is_integer(Limit), Limit > 0 ->
-    gen_server:call(?MODULE, {set_limit, Limit}).
-
 %% @doc Changes the configured value for a prune interval.
 %% Returns previous value.
 -spec set_prune_interval(pos_integer()) -> pos_integer().
@@ -122,18 +113,12 @@ init(_) ->
     ets:new(ken_pending, [named_table]),
     ets:new(ken_resubmit, [named_table]),
     ets:new(ken_workers, [named_table, public, {keypos, #job.name}]),
-    Limit = list_to_integer(config("limit", "20")),
-    {ok, #state{pruned_last = erlang:monotonic_time(), limit = Limit}}.
-
-terminate(_Reason, _State) ->
-    ok.
+    {ok, #state{pruned_last = erlang:monotonic_time()}}.
 
 handle_call({set_batch_size, BS}, _From, #state{batch_size = Old} = State) ->
     {reply, Old, State#state{batch_size = BS}, 0};
 handle_call({set_delay, Delay}, _From, #state{delay = Old} = State) ->
     {reply, Old, State#state{delay = Delay}, 0};
-handle_call({set_limit, Limit}, _From, #state{limit = Old} = State) ->
-    {reply, Old, State#state{limit = Limit}, 0};
 handle_call({set_prune_interval, Interval}, _From, State) ->
     Old = State#state.prune_interval,
     {reply, Old, State#state{prune_interval = Interval}, 0};
@@ -171,6 +156,16 @@ handle_cast({trigger_update, #job{name = {_, _, hastings}, server = GPid, seq =
     Now = erlang:monotonic_time(),
     ets:insert(ken_workers, Job#job{worker_pid = Pid, lru = Now}),
     {noreply, State, 0};
+handle_cast({trigger_update, #job{name = {_, Index, nouveau}} = Job}, State) ->
+    % nouveau_index_manager:update_index will trigger a search index update.
+    {Pid, _} = erlang:spawn_monitor(
+        nouveau_index_manager,
+        update_index,
+        [Index]
+    ),
+    Now = erlang:monotonic_time(),
+    ets:insert(ken_workers, Job#job{worker_pid = Pid, lru = Now}),
+    {noreply, State, 0};
 % search index job names have 3 elements. See job record definition.
 handle_cast({trigger_update, #job{name = {_, _, _}, server = GPid, seq = Seq} = Job}, State) ->
     % dreyfus_index:await will trigger a search index update.
@@ -225,9 +220,6 @@ handle_info({'DOWN', _, _, Pid, Reason}, State) ->
 handle_info(Msg, State) ->
     {stop, {unknown_info, Msg}, State}.
 
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 %% private functions
 
 maybe_start_next_queued_job(#state{dbworker = {_, _}} = State) ->
@@ -275,22 +267,26 @@ get_active_count() ->
 
 % If any indexing job fails, resubmit requests for all indexes.
 update_db_indexes(Name, State) ->
-    {ok, DDocs} = design_docs(Name),
-    RandomSorted = lists:sort([{rand:uniform(), D} || D <- DDocs]),
-    Resubmit = lists:foldl(
-        fun({_, DDoc}, Acc) ->
-            JsonDDoc = couch_doc:from_json_obj(DDoc),
-            case update_ddoc_indexes(Name, JsonDDoc, State) of
-                ok -> Acc;
-                _ -> true
-            end
-        end,
-        false,
-        RandomSorted
-    ),
-    if
-        Resubmit -> exit(resubmit);
-        true -> ok
+    case design_docs(Name) of
+        {ok, DDocs} ->
+            RandomSorted = lists:sort([{rand:uniform(), D} || D <- DDocs]),
+            Resubmit = lists:foldl(
+                fun({_, DDoc}, Acc) ->
+                    JsonDDoc = couch_doc:from_json_obj(DDoc),
+                    case update_ddoc_indexes(Name, JsonDDoc, State) of
+                        ok -> Acc;
+                        _ -> true
+                    end
+                end,
+                false,
+                RandomSorted
+            ),
+            if
+                Resubmit -> exit(resubmit);
+                true -> ok
+            end;
+        {error, timeout} ->
+            exit(resubmit)
     end.
 
 design_docs(Name) ->
@@ -329,8 +325,9 @@ update_ddoc_indexes(Name, #doc{} = Doc, State) ->
         end,
     SearchUpdated = search_updated(Name, Doc, Seq, State),
     STUpdated = st_updated(Name, Doc, Seq, State),
-    case {ViewUpdated, SearchUpdated, STUpdated} of
-        {ok, ok, ok} -> ok;
+    NouveauUpdated = nouveau_updated(Name, Doc, Seq, State),
+    case {ViewUpdated, SearchUpdated, STUpdated, NouveauUpdated} of
+        {ok, ok, ok, ok} -> ok;
         _ -> resubmit
     end.
 
@@ -370,6 +367,19 @@ st_updated(_Name, _Doc, _Seq, _State) ->
     ok.
 -endif.
 
+nouveau_updated(Name, Doc, Seq, State) ->
+    case should_update(Doc, <<"nouveau">>) of
+        true ->
+            try nouveau_util:design_doc_to_indexes(Name, Doc) of
+                SIndexes -> update_ddoc_nouveau_indexes(Name, SIndexes, Seq, State)
+            catch
+                _:_ ->
+                    ok
+            end;
+        false ->
+            ok
+    end.
+
 should_update(#doc{body = {Props}}, IndexType) ->
     case couch_util:get_value(<<"autoupdate">>, Props) of
         false ->
@@ -451,16 +461,39 @@ update_ddoc_st_indexes(DbName, Indexes, Seq, State) ->
     end.
 -endif.
 
+update_ddoc_nouveau_indexes(DbName, Indexes, Seq, State) ->
+    if
+        Indexes =/= [] ->
+            % Spawn a job for each search index in the ddoc
+            lists:foldl(
+                fun(Index, Acc) ->
+                    case maybe_start_job({DbName, Index, nouveau}, nil, Seq, State) of
+                        resubmit -> resubmit;
+                        _ -> Acc
+                    end
+                end,
+                ok,
+                Indexes
+            );
+        true ->
+            ok
+    end.
+
 should_start_job(#job{name = Name, seq = Seq, server = Pid}, State) ->
     Threshold = list_to_integer(config("max_incremental_updates", "1000")),
     IncrementalChannels = list_to_integer(config("incremental_channels", "80")),
     BatchChannels = list_to_integer(config("batch_channels", "20")),
     TotalChannels = IncrementalChannels + BatchChannels,
+    BlockBackgroundViewIndexing = couch_disk_monitor:block_background_view_indexing(),
+    % View name has two elements
+    IsView = tuple_size(Name) == 2,
     A = get_active_count(),
     #state{delay = Delay, batch_size = BS} = State,
     case ets:lookup(ken_workers, Name) of
         [] ->
             if
+                BlockBackgroundViewIndexing andalso IsView ->
+                    false;
                 A < BatchChannels ->
                     true;
                 A < TotalChannels ->
@@ -470,12 +503,15 @@ should_start_job(#job{name = Name, seq = Seq, server = Pid}, State) ->
                             {ok, CurrentSeq} = hastings_index:await(Pid, 0),
                             (Seq - CurrentSeq) < Threshold;
                         % View name has two elements.
-                        {_, _} ->
+                        _ when IsView ->
                             % Since seq is 0, couch_index:get_state/2 won't
                             % spawn an index update.
                             {ok, MRSt} = couch_index:get_state(Pid, 0),
                             CurrentSeq = couch_mrview_index:get(update_seq, MRSt),
                             (Seq - CurrentSeq) < Threshold;
+                        % Nouveau has three elements
+                        {_, Index, nouveau} ->
+                            nouveau_index_updater:outdated(Index);
                         % Search name has three elements.
                         {_, _, _} ->
                             {ok, _IndexPid, CurrentSeq} = dreyfus_index:await(Pid, 0),
@@ -491,6 +527,8 @@ should_start_job(#job{name = Name, seq = Seq, server = Pid}, State) ->
             Now = erlang:monotonic_time(),
             DeltaT = erlang:convert_time_unit(Now - LRU, native, millisecond),
             if
+                BlockBackgroundViewIndexing andalso IsView ->
+                    false;
                 A < BatchChannels, (Seq - OldSeq) >= BS ->
                     true;
                 A < BatchChannels, DeltaT > Delay ->
