@@ -22,12 +22,12 @@
     to_json/1,
     columns/1,
     is_usable/3,
-    get_default_field_options/1
+    get_default_field_options/1,
+    indexable_fields/1
 ]).
 
 -include_lib("couch/include/couch_db.hrl").
 -include("mango.hrl").
--include("mango_idx.hrl").
 
 validate_new(#idx{} = Idx, Db) ->
     {ok, Def} = do_validate(Idx#idx.def),
@@ -127,15 +127,25 @@ columns(Idx) ->
                 )
     end.
 
+% Mind that `is_usable/3` is not about "what fields can be answered by
+% the index" but instead more along the lines of "this index will
+% ensure that all the documents that should be returned for the query
+% will be, because we checked that all the bits of the query that
+% imply `$exists` for a field are used when we check that the indexing
+% process will have included all the relevant documents in the index".
+-spec is_usable(#idx{}, selector(), _) -> {boolean(), rejection_details()}.
 is_usable(_, Selector, _) when Selector =:= {[]} ->
-    false;
+    {false, #{reason => [empty_selector]}};
 is_usable(Idx, Selector, _) ->
     case columns(Idx) of
         all_fields ->
-            true;
+            {true, #{reason => []}};
         Cols ->
             Fields = indexable_fields(Selector),
-            sets:is_subset(sets:from_list(Fields), sets:from_list(Cols))
+            Usable = sets:is_subset(sets:from_list(Fields), sets:from_list(Cols)),
+            Reason = [field_mismatch || not Usable],
+            Details = #{reason => Reason},
+            {Usable, Details}
     end.
 
 do_validate({Props}) ->
@@ -303,10 +313,17 @@ construct_analyzer({Props}) ->
             ]}
     end.
 
+-spec indexable_fields(SelectorObject) -> Fields when
+    SelectorObject :: any(),
+    Fields :: [binary()].
+indexable_fields({[]}) ->
+    [];
 indexable_fields(Selector) ->
     TupleTree = mango_selector_text:convert([], Selector),
-    indexable_fields([], TupleTree).
+    lists:uniq(indexable_fields([], TupleTree)).
 
+-spec indexable_fields(Fields, abstract_text_selector()) -> Fields when
+    Fields :: [binary()].
 indexable_fields(Fields, {op_and, Args}) when is_list(Args) ->
     lists:foldl(
         fun(Arg, Fields0) -> indexable_fields(Fields0, Arg) end,
@@ -344,8 +361,6 @@ indexable_fields(Fields, {op_not, {ExistsQuery, Arg}}) when is_tuple(Arg) ->
 % forces "$exists" : false to use _all_docs
 indexable_fields(_, {op_not, {_, false}}) ->
     [];
-indexable_fields(Fields, {op_insert, Arg}) when is_binary(Arg) ->
-    Fields;
 %% fieldname.[]:length is not a user defined field.
 indexable_fields(Fields, {op_field, {[_, <<":length">>], _}}) ->
     Fields;
@@ -360,6 +375,11 @@ indexable_fields(Fields, {op_fieldname, {_, _}}) ->
 %% Similar idea to op_fieldname but with fieldname:null
 indexable_fields(Fields, {op_null, {_, _}}) ->
     Fields;
+%% Regular expression matching should be an exception to the rule
+%% above because the type of the associated field is exact, it must be
+%% a string.
+indexable_fields(Fields, {op_regex, Name}) ->
+    [iolist_to_binary([Name, ":string"]) | Fields];
 indexable_fields(Fields, {op_default, _}) ->
     [<<"$default">> | Fields].
 
@@ -456,4 +476,143 @@ warn_index_all({Idx, Db}) ->
         ?assertThrow({test_error, logged_warning}, validate_new(Idx, Db))
     end).
 
+indexable(Selector) ->
+    indexable_fields(test_util:as_selector(Selector)).
+
+indexable_fields_test() ->
+    ?assertEqual(
+        [<<"$default">>, <<"field1:boolean">>, <<"field2:number">>, <<"field3:string">>],
+        indexable(
+            #{
+                <<"$default">> => #{<<"$text">> => <<"text">>},
+                <<"field1">> => true,
+                <<"field2">> => 42,
+                <<"field3">> => #{<<"$regex">> => <<".*">>}
+            }
+        )
+    ),
+    ?assertEqual(
+        [<<"f1:string">>, <<"f2:string">>, <<"f3:string">>, <<"f4:string">>, <<"f5:string">>],
+        lists:sort(
+            indexable(
+                #{
+                    <<"$and">> =>
+                        [
+                            #{<<"f1">> => <<"v1">>},
+                            #{<<"f2">> => <<"v2">>}
+                        ],
+                    <<"$or">> =>
+                        [
+                            #{<<"f3">> => <<"v3">>},
+                            #{<<"f4">> => <<"v4">>}
+                        ],
+                    <<"$not">> => #{<<"f5">> => <<"v5">>}
+                }
+            )
+        )
+    ),
+    ?assertEqual(
+        [<<"f2:string">>, <<"f3:string">>, <<"f1:string">>],
+        indexable(
+            #{
+                <<"$and">> =>
+                    [
+                        #{<<"f2">> => <<"v1">>},
+                        #{<<"f2">> => <<"v2">>}
+                    ],
+                <<"$not">> => #{<<"f3">> => <<"v5">>},
+                <<"$or">> =>
+                    [
+                        #{<<"f1">> => <<"v3">>},
+                        #{<<"f1">> => <<"v4">>}
+                    ]
+            }
+        )
+    ),
+    ?assertEqual(
+        [],
+        indexable(
+            #{
+                <<"field1">> => null,
+                <<"field2">> => #{<<"$size">> => 3},
+                <<"field3">> => #{<<"$type">> => <<"type">>}
+            }
+        )
+    ),
+    ?assertEqual(
+        [],
+        indexable(
+            #{
+                <<"$and">> =>
+                    [
+                        #{<<"f1">> => null},
+                        #{<<"f2">> => null}
+                    ],
+                <<"$or">> =>
+                    [
+                        #{<<"f3">> => null},
+                        #{<<"f4">> => null}
+                    ],
+                <<"$not">> => #{<<"f5">> => null}
+            }
+        )
+    ).
+
+usable(Index, undefined, Fields) ->
+    is_usable(Index, undefined, Fields);
+usable(Index, Selector, Fields) ->
+    is_usable(Index, test_util:as_selector(Selector), Fields).
+
+is_usable_test() ->
+    Usable = {true, #{reason => []}},
+    EmptySelector = {false, #{reason => [empty_selector]}},
+    FieldMismatch = {false, #{reason => [field_mismatch]}},
+    ?assertEqual(EmptySelector, usable(undefined, #{}, undefined)),
+
+    AllFieldsIndex = #idx{def = {[{<<"fields">>, <<"all_fields">>}]}},
+    ?assertEqual(Usable, usable(AllFieldsIndex, undefined, undefined)),
+
+    Field1 = {[{<<"name">>, <<"field1">>}, {<<"type">>, <<"string">>}]},
+    Field2 = {[{<<"name">>, <<"field2">>}, {<<"type">>, <<"number">>}]},
+    Index = #idx{def = {[{<<"fields">>, [Field1, Field2]}]}},
+    ?assertEqual(Usable, usable(Index, #{<<"field1">> => <<"value">>}, undefined)),
+    ?assertEqual(FieldMismatch, usable(Index, #{<<"field1">> => 42}, undefined)),
+    ?assertEqual(FieldMismatch, usable(Index, #{<<"field3">> => true}, undefined)),
+    ?assertEqual(
+        Usable, usable(Index, #{<<"field1">> => #{<<"$type">> => <<"string">>}}, undefined)
+    ),
+    ?assertEqual(
+        Usable, usable(Index, #{<<"field1">> => #{<<"$type">> => <<"boolean">>}}, undefined)
+    ),
+    ?assertEqual(
+        Usable, usable(Index, #{<<"field3">> => #{<<"$type">> => <<"boolean">>}}, undefined)
+    ),
+    ?assertEqual(Usable, usable(Index, #{<<"field1">> => #{<<"$exists">> => true}}, undefined)),
+    ?assertEqual(Usable, usable(Index, #{<<"field1">> => #{<<"$exists">> => false}}, undefined)),
+    ?assertEqual(Usable, usable(Index, #{<<"field3">> => #{<<"$exists">> => true}}, undefined)),
+    ?assertEqual(Usable, usable(Index, #{<<"field3">> => #{<<"$exists">> => false}}, undefined)),
+    ?assertEqual(
+        Usable,
+        usable(Index, #{<<"field1">> => #{<<"$regex">> => <<".*">>}}, undefined)
+    ),
+    ?assertEqual(
+        FieldMismatch,
+        usable(Index, #{<<"field2">> => #{<<"$regex">> => <<".*">>}}, undefined)
+    ),
+    ?assertEqual(
+        FieldMismatch,
+        usable(Index, #{<<"field3">> => #{<<"$regex">> => <<".*">>}}, undefined)
+    ),
+    ?assertEqual(
+        FieldMismatch,
+        usable(Index, #{<<"field1">> => #{<<"$nin">> => [1, 2, 3]}}, undefined)
+    ),
+    ?assertEqual(
+        Usable,
+        usable(Index, #{<<"field2">> => #{<<"$nin">> => [1, 2, 3]}}, undefined)
+    ),
+    ?assertEqual(
+        FieldMismatch,
+        usable(Index, #{<<"field3">> => #{<<"$nin">> => [1, 2, 3]}}, undefined)
+    ).
 -endif.
