@@ -26,12 +26,13 @@
 
     indexable_fields/1,
     field_ranges/1,
-    field_ranges/2
+    field_ranges/2,
+
+    covers/2
 ]).
 
 -include_lib("couch/include/couch_db.hrl").
 -include("mango.hrl").
--include("mango_idx.hrl").
 -include("mango_idx_view.hrl").
 
 validate_new(#idx{} = Idx, _Db) ->
@@ -112,6 +113,7 @@ columns(Idx) ->
     {<<"fields">>, {Fields}} = lists:keyfind(<<"fields">>, 1, Props),
     [Key || {Key, _} <- Fields].
 
+-spec is_usable(#idx{}, selector(), [field()]) -> {boolean(), rejection_details()}.
 is_usable(Idx, Selector, SortFields) ->
     % This index is usable if all of the columns are
     % restricted by the selector such that they are required to exist
@@ -129,9 +131,15 @@ is_usable(Idx, Selector, SortFields) ->
         [<<"_id">>, <<"_rev">>]
     ),
 
-    mango_selector:has_required_fields(Selector, RequiredFields2) andalso
-        not is_text_search(Selector) andalso
-        can_use_sort(RequiredFields, SortFields, Selector).
+    SelectorHasRequiredFields = mango_selector:has_required_fields(Selector, RequiredFields2),
+    NotTextSearch = not is_text_search(Selector),
+    CanUseSort = can_use_sort(RequiredFields, SortFields, Selector),
+    Reason =
+        [needs_text_search || not NotTextSearch] ++
+            [field_mismatch || not SelectorHasRequiredFields] ++
+            [sort_order_mismatch || not CanUseSort],
+    Details = #{reason => Reason},
+    {NotTextSearch andalso SelectorHasRequiredFields andalso CanUseSort, Details}.
 
 is_text_search({[]}) ->
     false;
@@ -298,6 +306,12 @@ indexable({[{<<"$gt">>, _}]}) ->
     true;
 indexable({[{<<"$gte">>, _}]}) ->
     true;
+indexable({[{<<"$beginsWith">>, _}]}) ->
+    true;
+% This is required to improve index selection for covering indexes.
+% Making `$exists` indexable should not cause problems in other cases.
+indexable({[{<<"$exists">>, _}]}) ->
+    true;
 % All other operators are currently not indexable.
 % This is also a subtle assertion that we don't
 % call indexable/1 on a field name.
@@ -333,7 +347,7 @@ range(Selector, Index) ->
     range(Selector, Index, '$gt', mango_json:min(), '$lt', mango_json:max()).
 
 % Adjust Low and High based on values found for the
-% givend Index in Selector.
+% given Index in Selector.
 range({[{<<"$and">>, Args}]}, Index, LCmp, Low, HCmp, High) ->
     lists:foldl(
         fun
@@ -386,7 +400,7 @@ range(_, _, LCmp, Low, HCmp, High) ->
 % check on Arg by setting LCmp == HCmp = '$eq' and Low == High == Arg.
 %
 % If 1 < N < 5 (mid), then we set High to Arg and Arg has just
-% narrowed our range. HCmp is set the the '$lt' operator that was
+% narrowed our range. HCmp is set the '$lt' operator that was
 % part of the input.
 %
 % If N == 5 (high), We just set HCmp to '$lt' since its guaranteed
@@ -400,6 +414,12 @@ range(_, _, LCmp, Low, HCmp, High) ->
 % operators but its all straight forward once you figure out how
 % we're basically just narrowing our logical ranges.
 
+% beginsWith requires both a high and low bound
+range({[{<<"$beginsWith">>, Arg}]}, LCmp, Low, HCmp, High) ->
+    {LCmp0, Low0, HCmp0, High0} = range({[{<<"$gte">>, Arg}]}, LCmp, Low, HCmp, High),
+    % U+FFFF is the highest sorting code point according to the collator rules,
+    % even though it's not the highest code point in UTF8.
+    range({[{<<"$lte">>, <<Arg/binary, 16#FFFF/utf8>>}]}, LCmp0, Low0, HCmp0, High0);
 range({[{<<"$lt">>, Arg}]}, LCmp, Low, HCmp, High) ->
     case range_pos(Low, Arg, High) of
         min ->
@@ -521,3 +541,176 @@ can_use_sort([Col | RestCols], SortFields, Selector) ->
         true -> can_use_sort(RestCols, SortFields, Selector);
         false -> false
     end.
+
+% There is no information available about the full set of fields which
+% comes the following consequences: an index cannot (reliably) cover
+% an "all fields" type of query and nested fields are out of scope.
+-spec covers(#idx{}, fields()) -> boolean().
+covers(_, all_fields) ->
+    false;
+covers(Idx, Fields) ->
+    case mango_idx:def(Idx) of
+        all_docs ->
+            false;
+        _ ->
+            Available = [<<"_id">> | columns(Idx)],
+            sets:is_subset(sets:from_list(Fields), sets:from_list(Available))
+    end.
+
+-ifdef(TEST).
+-include_lib("eunit/include/eunit.hrl").
+
+indexable_fields_of(Selector) ->
+    indexable_fields(test_util:as_selector(Selector)).
+
+indexable_fields_empty_test() ->
+    ?assertEqual([], indexable_fields_of(#{})).
+
+indexable_fields_and_test() ->
+    Selector = #{<<"$and">> => [#{<<"field1">> => undefined, <<"field2">> => undefined}]},
+    ?assertEqual([<<"field1">>, <<"field2">>], indexable_fields_of(Selector)).
+
+indexable_fields_or_test() ->
+    Selector = #{<<"$or">> => [#{<<"field1">> => undefined, <<"field2">> => undefined}]},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_nor_test() ->
+    Selector = #{<<"$nor">> => [#{<<"field1">> => undefined, <<"field2">> => undefined}]},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_all_test() ->
+    Selector = #{<<"field">> => #{<<"$all">> => []}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_elemMatch_test() ->
+    Selector = #{<<"field">> => #{<<"$elemMatch">> => #{}}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_allMatch_test() ->
+    Selector = #{<<"field">> => #{<<"$allMatch">> => #{}}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_keyMapMatch_test() ->
+    Selector = #{<<"field">> => #{<<"$keyMapMatch">> => #{}}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_in_test() ->
+    Selector = #{<<"field">> => #{<<"$in">> => []}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_nin_test() ->
+    Selector = #{<<"field">> => #{<<"$nin">> => []}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_not_test() ->
+    Selector = #{<<"field">> => #{<<"$not">> => #{}}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_lt_test() ->
+    Selector = #{<<"field">> => #{<<"$lt">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_lte_test() ->
+    Selector = #{<<"field">> => #{<<"$lte">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_eq_test() ->
+    Selector = #{<<"field">> => #{<<"$eq">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_ne_test() ->
+    Selector = #{<<"field">> => #{<<"$ne">> => undefined}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_gte_test() ->
+    Selector = #{<<"field">> => #{<<"$gte">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_beginswith_test() ->
+    Selector = #{<<"field">> => #{<<"$beginsWith">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_gt_test() ->
+    Selector = #{<<"field">> => #{<<"$gt">> => undefined}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_mod_test() ->
+    Selector = #{<<"field">> => #{<<"$mod">> => [0, 0]}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_regex_test() ->
+    Selector = #{<<"field">> => #{<<"$regex">> => undefined}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_exists_test() ->
+    Selector = #{<<"field">> => #{<<"$exists">> => true}},
+    ?assertEqual([<<"field">>], indexable_fields_of(Selector)).
+
+indexable_fields_type_test() ->
+    Selector = #{<<"field">> => #{<<"$type">> => undefined}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+indexable_fields_size_test() ->
+    Selector = #{<<"field">> => #{<<"$size">> => 0}},
+    ?assertEqual([], indexable_fields_of(Selector)).
+
+covers_all_fields_test() ->
+    ?assertNot(covers(undefined, all_fields)).
+
+covers_all_docs_test() ->
+    ?assertNot(covers(#idx{def = all_docs}, undefined)).
+
+covers_empty_index_test() ->
+    Index = #idx{def = {[{<<"fields">>, {[]}}]}},
+    ?assert(covers(Index, [])),
+    ?assert(covers(Index, [<<"_id">>])).
+
+covers_regular_index_test() ->
+    Index = #idx{def = {[{<<"fields">>, {[{field1, undefined}, {field2, undefined}]}}]}},
+    ?assert(covers(Index, [])),
+    ?assert(covers(Index, [<<"_id">>])),
+    ?assert(covers(Index, [field1])),
+    ?assert(covers(Index, [field2, field1])),
+    ?assert(covers(Index, [<<"_id">>, field1, field2])),
+    ?assertNot(covers(Index, [field3, field1, field2])).
+
+usable(Index, undefined, Fields) ->
+    is_usable(Index, undefined, Fields);
+usable(Index, Selector, Fields) ->
+    is_usable(Index, test_util:as_selector(Selector), Fields).
+
+is_usable_test() ->
+    Usable = {true, #{reason => []}},
+    NeedsTextSearch = {false, #{reason => [needs_text_search, field_mismatch]}},
+    FieldMismatch = {false, #{reason => [field_mismatch]}},
+    SortOrderMismatch = {false, #{reason => [sort_order_mismatch]}},
+
+    Index = #idx{
+        def = {[{<<"fields">>, {[{<<"field1">>, undefined}, {<<"field2">>, undefined}]}}]}
+    },
+    ?assertEqual(FieldMismatch, usable(Index, #{}, [])),
+    ?assertEqual(FieldMismatch, usable(Index, #{<<"field1">> => <<"value1">>}, [])),
+    ?assertEqual(
+        NeedsTextSearch,
+        usable(
+            Index,
+            #{
+                <<"$or">> => [
+                    #{<<"$text">> => <<"foobar">>},
+                    #{<<"field1">> => <<"value1">>}
+                ],
+                <<"field2">> => 42
+            },
+            []
+        )
+    ),
+    ?assertEqual(
+        SortOrderMismatch,
+        usable(Index, #{<<"field1">> => <<"value1">>, <<"field2">> => 42}, [
+            <<"field3">>, <<"field4">>
+        ])
+    ),
+    ?assertEqual(
+        Usable, usable(Index, #{<<"field1">> => <<"value1">>, <<"field2">> => <<"value2">>}, [])
+    ).
+-endif.
