@@ -25,6 +25,7 @@
     ushards/1, ushards/2
 ]).
 -export([get_shard/3, local_shards/1, shard_suffix/1, fold_shards/2]).
+-export([fold_dbs/2, fold_dbs/3]).
 -export([sync_security/0, sync_security/1]).
 -export([compare_nodelists/0, compare_shards/1]).
 -export([quorum/1, group_by_proximity/1]).
@@ -32,14 +33,16 @@
 -export([belongs/2, owner/3]).
 -export([get_placement/1]).
 -export([ping/1, ping/2]).
+-export([ping_nodes/0, ping_nodes/1, ping_nodes/2]).
+-export([dead_nodes/0, dead_nodes/1]).
 -export([db_is_current/1]).
 -export([shard_creation_time/1]).
+-export([generate_shard_suffix/0]).
 
 %% For mem3 use only.
 -export([name/1, node/1, range/1, engine/1]).
 
 -include_lib("mem3/include/mem3.hrl").
--include_lib("couch/include/couch_db.hrl").
 
 -define(PING_TIMEOUT_IN_MS, 60000).
 
@@ -128,7 +131,7 @@ shards_int(DbName, Options) ->
             %% and view_all_docs
             [
                 #ordered_shard{
-                    node = node(),
+                    node = config:node_name(),
                     name = ShardDbName,
                     dbname = ShardDbName,
                     range = [0, (2 bsl 31) - 1],
@@ -141,7 +144,7 @@ shards_int(DbName, Options) ->
             %% and view_all_docs
             [
                 #shard{
-                    node = node(),
+                    node = config:node_name(),
                     name = ShardDbName,
                     dbname = ShardDbName,
                     range = [0, (2 bsl 31) - 1],
@@ -216,6 +219,12 @@ shard_creation_time(DbName0) ->
 fold_shards(Fun, Acc) ->
     mem3_shards:fold(Fun, Acc).
 
+fold_dbs(Fun, Acc) when is_function(Fun, 2) ->
+    mem3_shards:fold_dbs(<<>>, Fun, Acc).
+
+fold_dbs(<<Prefix/binary>>, Fun, Acc) when is_function(Fun, 2) ->
+    mem3_shards:fold_dbs(Prefix, Fun, Acc).
+
 sync_security() ->
     mem3_sync_security:go().
 
@@ -266,7 +275,7 @@ choose_shards(DbName, Nodes, Options) ->
     mem3_util:create_partition_map(DbName, N, Q, RotatedNodes, Suffix).
 
 rotate_rand(Nodes) ->
-    {A, B} = lists:split(couch_rand:uniform(length(Nodes)), Nodes),
+    {A, B} = lists:split(rand:uniform(length(Nodes)), Nodes),
     B ++ A.
 
 get_placement(Options) ->
@@ -295,7 +304,7 @@ decode_placement_string(PlacementStr) ->
 dbname(#shard{dbname = DbName}) ->
     DbName;
 dbname(<<"shards/", _:8/binary, "-", _:8/binary, "/", DbName/binary>>) ->
-    list_to_binary(filename:rootname(binary_to_list(DbName)));
+    strip_shard_suffix(DbName);
 dbname(DbName) when is_list(DbName) ->
     dbname(list_to_binary(DbName));
 dbname(DbName) when is_binary(DbName) ->
@@ -354,10 +363,10 @@ group_by_proximity(Shards) ->
 
 group_by_proximity(Shards, ZoneMap) ->
     {Local, Remote} = lists:partition(
-        fun(S) -> mem3:node(S) =:= node() end,
+        fun(S) -> mem3:node(S) =:= config:node_name() end,
         Shards
     ),
-    LocalZone = proplists:get_value(node(), ZoneMap),
+    LocalZone = proplists:get_value(config:node_name(), ZoneMap),
     Fun = fun(S) -> proplists:get_value(mem3:node(S), ZoneMap) =:= LocalZone end,
     {SameZone, DifferentZone} = lists:partition(Fun, Remote),
     {Local, SameZone, DifferentZone}.
@@ -422,31 +431,127 @@ engine(Opts) when is_list(Opts) ->
 %% Check whether a node is up or down
 %%  side effect: set up a connection to Node if there not yet is one.
 
--spec ping(Node :: atom()) -> pong | pang.
+-spec ping(node()) -> pos_integer() | Error :: term().
 
 ping(Node) ->
-    ping(Node, ?PING_TIMEOUT_IN_MS).
+    [{Node, Res}] = ping_nodes([Node]),
+    Res.
 
--spec ping(Node :: atom(), Timeout :: pos_integer()) -> pong | pang.
+-spec ping(node(), Timeout :: pos_integer()) -> pos_integer() | Error :: term().
 
 ping(Node, Timeout) when is_atom(Node) ->
-    %% The implementation of the function is copied from
-    %% lib/kernel/src/net_adm.erl with addition of a Timeout
-    case
-        catch gen:call(
-            {net_kernel, Node},
-            '$gen_call',
-            {is_auth, node()},
-            Timeout
-        )
-    of
-        {ok, yes} ->
-            pong;
-        _ ->
-            erlang:disconnect_node(Node),
-            pang
+    [{Node, Res}] = ping_nodes([Node], Timeout),
+    Res.
+
+-spec ping_nodes() -> [{node(), pos_integer() | Error :: term()}].
+
+ping_nodes() ->
+    ping_nodes(live_cluster_nodes(), ?PING_TIMEOUT_IN_MS).
+
+-spec ping_nodes(Timeout :: pos_integer()) -> [{node(), pos_integer() | Error :: term()}].
+
+ping_nodes(Timeout) when is_integer(Timeout), Timeout > 0 ->
+    ping_nodes(live_cluster_nodes(), Timeout).
+
+ping_nodes(Nodes, Timeout) ->
+    PidRefs = [spawn_monitor(fun() -> exit(do_ping(N, Timeout)) end) || N <- Nodes],
+    Refs = maps:from_keys([Ref || {_Pid, Ref} <- PidRefs], true),
+    UntilMSec = erlang:monotonic_time(millisecond) + Timeout,
+    Results = gather_ping_results(Refs, UntilMSec, #{}),
+    Fun = fun(Node, {_Pid, Ref}) -> {Node, map_get(Ref, Results)} end,
+    lists:sort(lists:zipwith(Fun, Nodes, PidRefs)).
+
+% Gather ping results but use an absolute time limit to avoid
+% waiting up to Timeout's worth of time per individual node.
+%
+gather_ping_results(Refs, _Until, Results) when map_size(Refs) == 0 ->
+    Results;
+gather_ping_results(Refs, Until, Results) ->
+    Timeout = Until - erlang:monotonic_time(millisecond),
+    case Timeout >= 0 of
+        true ->
+            receive
+                {'DOWN', Ref, _, _, Res} when is_map_key(Ref, Refs) ->
+                    Refs1 = maps:remove(Ref, Refs),
+                    Results1 = Results#{Ref => Res},
+                    gather_ping_results(Refs1, Until, Results1)
+            after min(100, Timeout) ->
+                gather_ping_results(Refs, Until, Results)
+            end;
+        false ->
+            Fun = fun(Ref, true, Acc) ->
+                erlang:demonitor(Ref, [flush]),
+                Acc#{Ref => timeout}
+            end,
+            maps:fold(Fun, Results, Refs)
     end.
 
+live_cluster_nodes() ->
+    mem3_util:live_nodes() -- [node()].
+
+do_ping(Node, Timeout) ->
+    T0 = erlang:monotonic_time(),
+    % This is the function called by net_adm ping. One difference is that
+    % net_adm ping on a failure will also forcibly disconnect a node
+    % which we don't do here:
+    %  https://github.com/erlang/otp/blob/master/lib/kernel/src/net_adm.erl#L97
+    try gen_server:call({net_kernel, Node}, {is_auth, node()}, Timeout) of
+        yes ->
+            erlang:convert_time_unit(erlang:monotonic_time() - T0, native, microsecond);
+        Error ->
+            Error
+    catch
+        exit:{GenServerErr, _Stack} ->
+            GenServerErr;
+        Tag:Err ->
+            {Tag, Err}
+    end.
+
+-spec dead_nodes() -> [node() | Error :: term()].
+
+%% @doc Returns a list of dead nodes from the cluster.
+%%
+%% "dead" node is a node which appears in the mem3:nodes() list but is not
+%% connected. Dead nodes are included in the result if it's considered
+%% "dead" by any of the reachable nodes or doesn't respond or timeout when
+%% queried by the multicall/2.
+%%
+%% dead_nodes(TimeoutInMSec) will use the timeout for the rpc:multicall. If any
+%% node fails to respond in that time, it will be added to the dead nodes
+%% response list as well.
+%%
+%% The default timeout is 30 seconds
+%%
+dead_nodes() ->
+    dead_nodes(?PING_TIMEOUT_IN_MS).
+
+-spec dead_nodes(Timeout :: pos_integer()) -> [node() | Error :: term()].
+
+dead_nodes(Timeout) when is_integer(Timeout), Timeout > 0 ->
+    % Here we are trying to detect overlapping partitions where not all the
+    % nodes connect to each other. For example: n1 connects to n2 and n3, but
+    % n2 and n3 are not connected.
+    DeadFun = fun() ->
+        Expected = ordsets:from_list(mem3:nodes()),
+        Live = ordsets:from_list(mem3_util:live_nodes()),
+        Dead = ordsets:subtract(Expected, Live),
+        ordsets:to_list(Dead)
+    end,
+    {Responses, BadNodes} = multicall(DeadFun, Timeout),
+    AccF = lists:foldl(
+        fun
+            (Dead, Acc) when is_list(Dead) -> ordsets:union(Acc, Dead);
+            (Error, Acc) -> ordsets:union(Acc, [Error])
+        end,
+        ordsets:from_list(BadNodes),
+        Responses
+    ),
+    ordsets:to_list(AccF).
+
+multicall(Fun, Timeout) when is_integer(Timeout), Timeout > 0 ->
+    F = fun() -> catch Fun() end,
+    rpc:multicall(erlang, apply, [F, []], Timeout).
+
 db_is_current(#shard{name = Name}) ->
     db_is_current(Name);
 db_is_current(<<"shards/", _/binary>> = Name) ->
@@ -462,6 +567,26 @@ db_is_current(Name) when is_binary(Name) ->
     % for unit tests that either test or use mem3_rep logic
     couch_server:exists(Name).
 
+generate_shard_suffix() ->
+    UnixSeconds = os:system_time(second),
+    "." ++ integer_to_list(UnixSeconds).
+
+strip_shard_suffix(DbName) when is_binary(DbName) ->
+    % length(".1684269710") = 11. On 2286-11-20 the timestamp would flip to 11
+    % digits so we'd have to increase length to 12 then.
+    case DbName of
+        <<Prefix:(byte_size(DbName) - 11)/binary, $., Ts/binary>> ->
+            try
+                _ = binary_to_integer(Ts),
+                Prefix
+            catch
+                error:badarg ->
+                    filename:rootname(DbName)
+            end;
+        _ ->
+            filename:rootname(DbName)
+    end.
+
 -ifdef(TEST).
 
 -include_lib("eunit/include/eunit.hrl").
@@ -505,4 +630,34 @@ rotate_rand_distribution_test() ->
     Cases = [rotate_rand([1, 2, 3]) || _ <- lists:seq(1, 100)],
     ?assertEqual(3, length(lists:usort(Cases))).
 
+strip_shard_suffix_test_() ->
+    Prefix = <<"shards/c0000000-ffffffff/">>,
+    [
+        {DbName, ?_assertEqual(Res, dbname(<<Prefix/binary, DbName/binary>>))}
+     || {Res, DbName} <- [
+            {<<"foo">>, <<"foo.1684269710">>},
+            {<<"foo">>, <<"foo.168426971z">>},
+            {<<"foo/bar">>, <<"foo/bar.1684269710">>},
+            {<<"foo">>, <<"foo.1">>},
+            {<<"foo">>, <<"foo.abc">>},
+            {<<"foo">>, <<"foo.1111111111111111">>},
+            {<<"">>, <<"">>},
+            {<<"/">>, <<"/">>},
+            {<<"//">>, <<"//">>},
+            {<<"/.foo">>, <<"/.foo">>},
+            {<<".">>, <<"..">>},
+            {<<".">>, <<"..foo">>}
+        ]
+    ].
+
+shard_suffix_test() ->
+    % Assert a few basic things about the db suffixes we generate. If we change
+    % this scheme make sure to update strip_shard_suffix/1 and other places
+    % which assume the suffix is a 10 digit unix timestamp.
+    Suffix = generate_shard_suffix(),
+    ?assertEqual($., hd(Suffix)),
+    ?assertEqual(11, length(Suffix)),
+    [$. | Timestamp] = Suffix,
+    ?assert(is_integer(list_to_integer(Timestamp))).
+
 -endif.
