@@ -44,8 +44,7 @@
     terminate/2,
     handle_call/3,
     handle_cast/2,
-    handle_info/2,
-    code_change/3
+    handle_info/2
 ]).
 
 -include("mem3_reshard.hrl").
@@ -356,9 +355,6 @@ handle_info(Info, State) ->
     couch_log:error("~p unexpected info ~p", [?MODULE, Info]),
     {noreply, State}.
 
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 %% Private API
 
 validate_and_start_job(#shard{} = Source, Split) ->
@@ -616,7 +612,7 @@ state_id() ->
 
 -spec job_id(#job{}) -> binary().
 job_id(#job{source = #shard{name = SourceName}}) ->
-    HashInput = [SourceName, atom_to_binary(node(), utf8)],
+    HashInput = [SourceName, atom_to_binary(config:node_name(), utf8)],
     IdHashList = couch_util:to_hex(crypto:hash(sha256, HashInput)),
     IdHash = iolist_to_binary(IdHashList),
     Prefix = iolist_to_binary(io_lib:format("~3..0B", [?JOB_ID_VERSION])),
@@ -650,7 +646,7 @@ target_ranges([Begin, End], Split) when
 
 -spec build_shard([non_neg_integer()], binary(), binary()) -> #shard{}.
 build_shard(Range, DbName, Suffix) ->
-    Shard = #shard{dbname = DbName, range = Range, node = node()},
+    Shard = #shard{dbname = DbName, range = Range, node = config:node_name()},
     mem3_util:name_shard(Shard, <<".", Suffix/binary>>).
 
 -spec running_jobs() -> [#job{}].
