@@ -12,16 +12,16 @@
 
 -module(mem3_shards).
 -behaviour(gen_server).
--vsn(3).
 -behaviour(config_listener).
 
--export([init/1, terminate/2, code_change/3]).
+-export([init/1, terminate/2]).
 -export([handle_call/3, handle_cast/2, handle_info/2]).
 -export([handle_config_change/5, handle_config_terminate/3]).
 
 -export([start_link/0]).
 -export([opts_for_db/1]).
 -export([for_db/1, for_db/2, for_docid/2, for_docid/3, get/3, local/1, fold/2]).
+-export([fold_dbs/3]).
 -export([for_shard_range/1]).
 -export([set_max_size/1]).
 -export([get_changes_pid/0]).
@@ -160,8 +160,9 @@ get(DbName, Node, Range) ->
 local(DbName) when is_list(DbName) ->
     local(list_to_binary(DbName));
 local(DbName) ->
+    ThisNode = config:node_name(),
     Pred = fun
-        (#shard{node = Node}) when Node == node() -> true;
+        (#shard{node = Node}) when Node == ThisNode -> true;
         (_) -> false
     end,
     lists:filter(Pred, for_db(DbName)).
@@ -177,6 +178,23 @@ fold(Fun, Acc) ->
         couch_db:close(Db)
     end.
 
+fold_dbs(<<Prefix/binary>>, Fun, Acc0) when is_function(Fun, 2) ->
+    {ok, Db} = mem3_util:ensure_exists(mem3_sync:shards_db()),
+    Len = byte_size(Prefix),
+    FoldFun = fun(#full_doc_info{id = Id}, Acc) ->
+        case Id of
+            <<Prefix:Len/binary, _/binary>> -> {ok, Fun(Id, Acc)};
+            <<_/binary>> -> {stop, Acc}
+        end
+    end,
+    Opts = [{start_key, Prefix}],
+    try
+        {ok, LastAcc} = couch_db:fold_docs(Db, FoldFun, Acc0, Opts),
+        LastAcc
+    after
+        couch_db:close(Db)
+    end.
+
 set_max_size(Size) when is_integer(Size), Size > 0 ->
     gen_server:call(?MODULE, {set_max_size, Size}).
 
@@ -302,9 +320,6 @@ terminate(_Reason, #st{changes_pid = Pid}) ->
     exit(Pid, kill),
     ok.
 
-code_change(_OldVsn, #st{} = St, _Extra) ->
-    {ok, St}.
-
 %% internal functions
 
 start_changes_listener(SinceSeq) ->
@@ -389,7 +404,7 @@ changes_callback({change, {Change}, _}, _) ->
                                 create_if_missing(mem3:name(S))
                              || S <-
                                     Shards,
-                                mem3:node(S) =:= node()
+                                mem3:node(S) =:= config:node_name()
                             ]
                     end
             end
