@@ -12,15 +12,12 @@
 
 -module(mem3_sync_event).
 -behaviour(gen_event).
--vsn(1).
 
 -export([
     init/1,
     handle_event/2,
     handle_call/2,
-    handle_info/2,
-    terminate/2,
-    code_change/3
+    handle_info/2
 ]).
 
 init(_) ->
@@ -51,12 +48,6 @@ handle_info({nodedown, Node}, State) ->
 handle_info(_Info, State) ->
     {ok, State}.
 
-terminate(_Reason, _State) ->
-    ok.
-
-code_change(_OldVsn, State, _Extra) ->
-    {ok, State}.
-
 drain_nodeups(Acc) ->
     receive
         {nodeup, Node} ->
