@@ -13,13 +13,15 @@
 
 -export([parse/2, usage/2, usage/3, usage/4]).
 
--export_type([arg_type/0,
-	      arg_value/0,
-	      arg_spec/0,
-	      simple_option/0,
-	      compound_option/0,
-	      option/0,
-	      option_spec/0]).
+-export_type([
+    arg_type/0,
+    arg_value/0,
+    arg_spec/0,
+    simple_option/0,
+    compound_option/0,
+    option/0,
+    option_spec/0
+]).
 
 -define(TAB_LENGTH, 8).
 %% Indentation of the help messages in number of tabs.
@@ -34,7 +36,6 @@
 
 -define(IS_OPT_SPEC(Opt), (tuple_size(Opt) =:= ?OPT_HELP)).
 
-
 %% Atom indicating the data type that an argument can be converted to.
 -type arg_type() :: 'atom' | 'binary' | 'boolean' | 'float' | 'integer' | 'string'.
 %% Data type that an argument can be converted to.
@@ -47,16 +48,15 @@
 -type option() :: simple_option() | compound_option().
 %% Command line option specification.
 -type option_spec() :: {
-                   Name    :: atom(),
-                   Short   :: char() | undefined,
-                   Long    :: string() | undefined,
-                   ArgSpec :: arg_spec(),
-                   Help    :: string() | undefined
-                  }.
+    Name :: atom(),
+    Short :: char() | undefined,
+    Long :: string() | undefined,
+    ArgSpec :: arg_spec(),
+    Help :: string() | undefined
+}.
 %% Output streams
 -type output_stream() :: 'standard_io' | 'standard_error'.
 
-
 %% @doc  Parse the command line options and arguments returning a list of tuples
 %%       and/or atoms using the Erlang convention for sending options to a
 %%       function.
@@ -64,19 +64,19 @@
     {ok, {[option()], [string()]}} | {error, {Reason :: atom(), Data :: any()}}.
 parse(OptSpecList, CmdLine) ->
     try
-        Args = if
-                   is_integer(hd(CmdLine)) ->
-                       string:tokens(CmdLine, " \t\n");
-                   true ->
-                       CmdLine
-               end,
+        Args =
+            if
+                is_integer(hd(CmdLine)) ->
+                    string:tokens(CmdLine, " \t\n");
+                true ->
+                    CmdLine
+            end,
         parse(OptSpecList, [], [], 0, Args)
     catch
-        throw: {error, {_Reason, _Data}} = Error ->
+        throw:{error, {_Reason, _Data}} = Error ->
             Error
     end.
 
-
 -spec parse([option_spec()], [option()], [string()], integer(), [string()]) ->
     {ok, {[option()], [string()]}}.
 %% Process the option terminator.
@@ -102,27 +102,28 @@ parse(OptSpecList, OptAcc, ArgAcc, _ArgPos, []) ->
     %% not present but had default arguments in the specification.
     {ok, {lists:reverse(append_default_options(OptSpecList, OptAcc)), lists:reverse(ArgAcc)}}.
 
-
 %% @doc Parse a long option, add it to the option accumulator and continue
 %%      parsing the rest of the arguments recursively.
 %%      A long option can have the following syntax:
 %%        --foo      Single option 'foo', no argument
 %%        --foo=bar  Single option 'foo', argument "bar"
 %%        --foo bar  Single option 'foo', argument "bar"
--spec parse_long_option([option_spec()], [option()], [string()], integer(), [string()], string(), string()) ->
-          {ok, {[option()], [string()]}}.
+-spec parse_long_option(
+    [option_spec()], [option()], [string()], integer(), [string()], string(), string()
+) ->
+    {ok, {[option()], [string()]}}.
 parse_long_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, OptArg) ->
     case split_assigned_arg(OptArg) of
         {Long, Arg} ->
             %% Get option that has its argument within the same string
             %% separated by an equal ('=') character (e.g. "--port=1000").
-            parse_long_option_assigned_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, Long, Arg);
-
+            parse_long_option_assigned_arg(
+                OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, Long, Arg
+            );
         Long ->
             case lists:keyfind(Long, ?OPT_LONG, OptSpecList) of
                 {Name, _Short, Long, undefined, _Help} ->
                     parse(OptSpecList, [Name | OptAcc], ArgAcc, ArgPos, Args);
-
                 {_Name, _Short, Long, _ArgSpec, _Help} = OptSpec ->
                     %% The option argument string is empty, but the option requires
                     %% an argument, so we look into the next string in the list.
@@ -133,13 +134,20 @@ parse_long_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, OptArg) ->
             end
     end.
 
-
 %% @doc Parse an option where the argument is 'assigned' in the same string using
 %%      the '=' character, add it to the option accumulator and continue parsing the
 %%      rest of the arguments recursively. This syntax is only valid for long options.
--spec parse_long_option_assigned_arg([option_spec()], [option()], [string()], integer(),
-                                     [string()], string(), string(), string()) ->
-                                            {ok, {[option()], [string()]}}.
+-spec parse_long_option_assigned_arg(
+    [option_spec()],
+    [option()],
+    [string()],
+    integer(),
+    [string()],
+    string(),
+    string(),
+    string()
+) ->
+    {ok, {[option()], [string()]}}.
 parse_long_option_assigned_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, Long, Arg) ->
     case lists:keyfind(Long, ?OPT_LONG, OptSpecList) of
         {_Name, _Short, Long, ArgSpec, _Help} = OptSpec ->
@@ -147,13 +155,18 @@ parse_long_option_assigned_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr
                 undefined ->
                     throw({error, {invalid_option_arg, OptStr}});
                 _ ->
-                    parse(OptSpecList, add_option_with_assigned_arg(OptSpec, Arg, OptAcc), ArgAcc, ArgPos, Args)
+                    parse(
+                        OptSpecList,
+                        add_option_with_assigned_arg(OptSpec, Arg, OptAcc),
+                        ArgAcc,
+                        ArgPos,
+                        Args
+                    )
             end;
         false ->
             throw({error, {invalid_option, OptStr}})
     end.
 
-
 %% @doc Split an option string that may contain an option with its argument
 %%      separated by an equal ('=') character (e.g. "port=1000").
 -spec split_assigned_arg(string()) -> {Name :: string(), Arg :: string()} | string().
@@ -167,11 +180,12 @@ split_assigned_arg(OptStr, [Char | Tail], Acc) ->
 split_assigned_arg(OptStr, [], _Acc) ->
     OptStr.
 
-
 %% @doc Retrieve the argument for an option from the next string in the list of
 %%      command-line parameters or set the value of the argument from the argument
 %%      specification (for boolean and integer arguments), if possible.
-parse_long_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _Short, _Long, ArgSpec, _Help} = OptSpec) ->
+parse_long_option_next_arg(
+    OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _Short, _Long, ArgSpec, _Help} = OptSpec
+) ->
     ArgSpecType = arg_spec_type(ArgSpec),
     case Args =:= [] orelse is_implicit_arg(ArgSpecType, hd(Args)) of
         true ->
@@ -179,14 +193,15 @@ parse_long_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _Sh
         false ->
             [Arg | Tail] = Args,
             try
-                parse(OptSpecList, [{Name, to_type(ArgSpecType, Arg)} | OptAcc], ArgAcc, ArgPos, Tail)
+                parse(
+                    OptSpecList, [{Name, to_type(ArgSpecType, Arg)} | OptAcc], ArgAcc, ArgPos, Tail
+                )
             catch
                 error:_ ->
                     throw({error, {invalid_option_arg, {Name, Arg}}})
             end
     end.
 
-
 %% @doc Parse a short option, add it to the option accumulator and continue
 %%      parsing the rest of the arguments recursively.
 %%      A short option can have the following syntax:
@@ -196,7 +211,9 @@ parse_long_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _Sh
 %%        -abc     Multiple options: 'a'; 'b'; 'c'
 %%        -bcafoo  Multiple options: 'b'; 'c'; 'a' with argument "foo"
 %%        -aaa     Multiple repetitions of option 'a' (only valid for options with integer arguments)
--spec parse_short_option([option_spec()], [option()], [string()], integer(), [string()], string(), string()) ->
+-spec parse_short_option(
+    [option_spec()], [option()], [string()], integer(), [string()], string(), string()
+) ->
     {ok, {[option()], [string()]}}.
 parse_short_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, OptArg) ->
     parse_short_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, first, OptArg).
@@ -204,45 +221,68 @@ parse_short_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, OptArg) ->
 parse_short_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptStr, OptPos, [Short | Arg]) ->
     case lists:keyfind(Short, ?OPT_SHORT, OptSpecList) of
         {Name, Short, _Long, undefined, _Help} ->
-            parse_short_option(OptSpecList, [Name | OptAcc], ArgAcc, ArgPos, Args, OptStr, first, Arg);
-
+            parse_short_option(
+                OptSpecList, [Name | OptAcc], ArgAcc, ArgPos, Args, OptStr, first, Arg
+            );
         {_Name, Short, _Long, ArgSpec, _Help} = OptSpec ->
             %% The option has a specification, so it requires an argument.
             case Arg of
                 [] ->
                     %% The option argument string is empty, but the option requires
                     %% an argument, so we look into the next string in the list.
-                    parse_short_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptSpec, OptPos);
-
+                    parse_short_option_next_arg(
+                        OptSpecList, OptAcc, ArgAcc, ArgPos, Args, OptSpec, OptPos
+                    );
                 _ ->
                     case is_valid_arg(ArgSpec, Arg) of
                         true ->
-                            parse(OptSpecList, add_option_with_arg(OptSpec, Arg, OptAcc), ArgAcc, ArgPos, Args);
+                            parse(
+                                OptSpecList,
+                                add_option_with_arg(OptSpec, Arg, OptAcc),
+                                ArgAcc,
+                                ArgPos,
+                                Args
+                            );
                         _ ->
-                            NewOptAcc = case OptPos of
-                                            first -> add_option_with_implicit_arg(OptSpec, OptAcc);
-                                            _     -> add_option_with_implicit_incrementable_arg(OptSpec, OptAcc)
-                                        end,
-                            parse_short_option(OptSpecList, NewOptAcc, ArgAcc, ArgPos, Args, OptStr, next, Arg)
+                            NewOptAcc =
+                                case OptPos of
+                                    first -> add_option_with_implicit_arg(OptSpec, OptAcc);
+                                    _ -> add_option_with_implicit_incrementable_arg(OptSpec, OptAcc)
+                                end,
+                            parse_short_option(
+                                OptSpecList, NewOptAcc, ArgAcc, ArgPos, Args, OptStr, next, Arg
+                            )
                     end
             end;
-
         false ->
             throw({error, {invalid_option, OptStr}})
     end;
 parse_short_option(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, _OptStr, _OptPos, []) ->
     parse(OptSpecList, OptAcc, ArgAcc, ArgPos, Args).
 
-
 %% @doc Retrieve the argument for an option from the next string in the list of
 %%      command-line parameters or set the value of the argument from the argument
 %%      specification (for boolean and integer arguments), if possible.
-parse_short_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _Short, _Long, ArgSpec, _Help} = OptSpec, OptPos) ->
+parse_short_option_next_arg(
+    OptSpecList,
+    OptAcc,
+    ArgAcc,
+    ArgPos,
+    Args,
+    {Name, _Short, _Long, ArgSpec, _Help} = OptSpec,
+    OptPos
+) ->
     case Args =:= [] orelse is_implicit_arg(ArgSpec, hd(Args)) of
         true when OptPos =:= first ->
             parse(OptSpecList, add_option_with_implicit_arg(OptSpec, OptAcc), ArgAcc, ArgPos, Args);
         true ->
-            parse(OptSpecList, add_option_with_implicit_incrementable_arg(OptSpec, OptAcc), ArgAcc, ArgPos, Args);
+            parse(
+                OptSpecList,
+                add_option_with_implicit_incrementable_arg(OptSpec, OptAcc),
+                ArgAcc,
+                ArgPos,
+                Args
+            );
         false ->
             [Arg | Tail] = Args,
             try
@@ -253,12 +293,11 @@ parse_short_option_next_arg(OptSpecList, OptAcc, ArgAcc, ArgPos, Args, {Name, _S
             end
     end.
 
-
 %% @doc Find the option for the discrete argument in position specified in the
 %%      Pos argument.
 -spec find_non_option_arg([option_spec()], integer()) -> {value, option_spec()} | false.
 find_non_option_arg([{_Name, undefined, undefined, _ArgSpec, _Help} = OptSpec | _Tail], 0) ->
-     {value, OptSpec};
+    {value, OptSpec};
 find_non_option_arg([{_Name, undefined, undefined, _ArgSpec, _Help} | Tail], Pos) ->
     find_non_option_arg(Tail, Pos - 1);
 find_non_option_arg([_Head | Tail], Pos) ->
@@ -266,25 +305,25 @@ find_non_option_arg([_Head | Tail], Pos) ->
 find_non_option_arg([], _Pos) ->
     false.
 
-
 %% @doc Append options that were not present in the command line arguments with
 %%      their default arguments.
 -spec append_default_options([option_spec()], [option()]) -> [option()].
 append_default_options([{Name, _Short, _Long, {_Type, DefaultArg}, _Help} | Tail], OptAcc) ->
-    append_default_options(Tail,
-               case lists:keymember(Name, 1, OptAcc) of
-                   false ->
-                       [{Name, DefaultArg} | OptAcc];
-                   _ ->
-                       OptAcc
-               end);
+    append_default_options(
+        Tail,
+        case lists:keymember(Name, 1, OptAcc) of
+            false ->
+                [{Name, DefaultArg} | OptAcc];
+            _ ->
+                OptAcc
+        end
+    );
 %% For options with no default argument.
 append_default_options([_Head | Tail], OptAcc) ->
     append_default_options(Tail, OptAcc);
 append_default_options([], OptAcc) ->
     OptAcc.
 
-
 %% @doc Add an option with argument converting it to the data type indicated by the
 %%      argument specification.
 -spec add_option_with_arg(option_spec(), string(), [option()]) -> [option()].
@@ -301,7 +340,6 @@ add_option_with_arg({Name, _Short, _Long, ArgSpec, _Help} = OptSpec, Arg, OptAcc
             add_option_with_implicit_arg(OptSpec, OptAcc)
     end.
 
-
 %% @doc Add an option with argument that was part of an assignment expression
 %%      (e.g. "--verbose=3") converting it to the data type indicated by the
 %%      argument specification.
@@ -314,7 +352,6 @@ add_option_with_assigned_arg({Name, _Short, _Long, ArgSpec, _Help}, Arg, OptAcc)
             throw({error, {invalid_option_arg, {Name, Arg}}})
     end.
 
-
 %% @doc Add an option that required an argument but did not have one. Some data
 %%      types (boolean, integer) allow implicit or assumed arguments.
 -spec add_option_with_implicit_arg(option_spec(), [option()]) -> [option()].
@@ -333,9 +370,9 @@ add_option_with_implicit_arg({Name, _Short, _Long, ArgSpec, _Help}, OptAcc) ->
             throw({error, {missing_option_arg, Name}})
     end.
 
-
 %% @doc Add an option with an implicit or assumed argument.
--spec add_option_with_implicit_incrementable_arg(option_spec() | arg_spec(), [option()]) -> [option()].
+-spec add_option_with_implicit_incrementable_arg(option_spec() | arg_spec(), [option()]) ->
+    [option()].
 add_option_with_implicit_incrementable_arg({Name, _Short, _Long, ArgSpec, _Help}, OptAcc) ->
     case arg_spec_type(ArgSpec) of
         boolean ->
@@ -357,7 +394,6 @@ add_option_with_implicit_incrementable_arg({Name, _Short, _Long, ArgSpec, _Help}
             throw({error, {missing_option_arg, Name}})
     end.
 
-
 %% @doc Retrieve the data type form an argument specification.
 -spec arg_spec_type(arg_spec()) -> arg_type() | undefined.
 arg_spec_type({Type, _DefaultArg}) ->
@@ -365,7 +401,6 @@ arg_spec_type({Type, _DefaultArg}) ->
 arg_spec_type(Type) when is_atom(Type) ->
     Type.
 
-
 %% @doc Convert an argument string to its corresponding data type.
 -spec to_type(arg_spec() | arg_type(), string()) -> arg_value().
 to_type({Type, _DefaultArg}, Arg) ->
@@ -394,22 +429,19 @@ to_type(boolean, Arg) ->
 to_type(_Type, Arg) ->
     Arg.
 
-
 -spec is_arg_true(string()) -> boolean().
 is_arg_true(Arg) ->
     (Arg =:= "true") orelse (Arg =:= "t") orelse
-    (Arg =:= "yes") orelse (Arg =:= "y") orelse
-    (Arg =:= "on") orelse (Arg =:= "enabled") orelse
-    (Arg =:= "1").
-
+        (Arg =:= "yes") orelse (Arg =:= "y") orelse
+        (Arg =:= "on") orelse (Arg =:= "enabled") orelse
+        (Arg =:= "1").
 
 -spec is_arg_false(string()) -> boolean().
 is_arg_false(Arg) ->
     (Arg =:= "false") orelse (Arg =:= "f") orelse
-    (Arg =:= "no") orelse (Arg =:= "n") orelse
-    (Arg =:= "off") orelse (Arg =:= "disabled") orelse
-    (Arg =:= "0").
-
+        (Arg =:= "no") orelse (Arg =:= "n") orelse
+        (Arg =:= "off") orelse (Arg =:= "disabled") orelse
+        (Arg =:= "0").
 
 -spec is_valid_arg(arg_spec(), nonempty_string()) -> boolean().
 is_valid_arg({Type, _DefaultArg}, Arg) ->
@@ -423,7 +455,6 @@ is_valid_arg(float, Arg) ->
 is_valid_arg(_Type, _Arg) ->
     true.
 
-
 -spec is_implicit_arg(arg_spec(), nonempty_string()) -> boolean().
 is_implicit_arg({Type, _DefaultArg}, Arg) ->
     is_implicit_arg(Type, Arg);
@@ -434,20 +465,17 @@ is_implicit_arg(integer, Arg) ->
 is_implicit_arg(_Type, _Arg) ->
     false.
 
-
 -spec is_boolean_arg(string()) -> boolean().
 is_boolean_arg(Arg) ->
     LowerArg = string:to_lower(Arg),
     is_arg_true(LowerArg) orelse is_arg_false(LowerArg).
 
-
 -spec is_integer_arg(string()) -> boolean().
 is_integer_arg("-" ++ Tail) ->
     is_non_neg_integer_arg(Tail);
 is_integer_arg(Arg) ->
     is_non_neg_integer_arg(Arg).
 
-
 -spec is_non_neg_integer_arg(string()) -> boolean().
 is_non_neg_integer_arg([Head | Tail]) when Head >= $0, Head =< $9 ->
     is_non_neg_integer_arg(Tail);
@@ -456,7 +484,6 @@ is_non_neg_integer_arg([_Head | _Tail]) ->
 is_non_neg_integer_arg([]) ->
     true.
 
-
 -spec is_non_neg_float_arg(string()) -> boolean().
 is_non_neg_float_arg([Head | Tail]) when (Head >= $0 andalso Head =< $9) orelse Head =:= $. ->
     is_non_neg_float_arg(Tail);
@@ -465,41 +492,43 @@ is_non_neg_float_arg([_Head | _Tail]) ->
 is_non_neg_float_arg([]) ->
     true.
 
-
 %% @doc  Show a message on standard_error indicating the command line options and
 %%       arguments that are supported by the program.
 -spec usage([option_spec()], string()) -> ok.
 usage(OptSpecList, ProgramName) ->
-	usage(OptSpecList, ProgramName, standard_error).
-
+    usage(OptSpecList, ProgramName, standard_error).
 
 %% @doc  Show a message on standard_error or standard_io indicating the command line options and
 %%       arguments that are supported by the program.
 -spec usage([option_spec()], string(), output_stream() | string()) -> ok.
 usage(OptSpecList, ProgramName, OutputStream) when is_atom(OutputStream) ->
-    io:format(OutputStream, "Usage: ~s~s~n~n~s~n",
-              [ProgramName, usage_cmd_line(OptSpecList), usage_options(OptSpecList)]);
+    io:format(
+        OutputStream,
+        "Usage: ~s~s~n~n~s~n",
+        [ProgramName, usage_cmd_line(OptSpecList), usage_options(OptSpecList)]
+    );
 %% @doc  Show a message on standard_error indicating the command line options and
 %%       arguments that are supported by the program. The CmdLineTail argument
 %%       is a string that is added to the end of the usage command line.
 usage(OptSpecList, ProgramName, CmdLineTail) ->
-	usage(OptSpecList, ProgramName, CmdLineTail, standard_error).
-
+    usage(OptSpecList, ProgramName, CmdLineTail, standard_error).
 
 %% @doc  Show a message on standard_error or standard_io indicating the command line options and
 %%       arguments that are supported by the program. The CmdLineTail argument
 %%       is a string that is added to the end of the usage command line.
 -spec usage([option_spec()], string(), string(), output_stream() | [{string(), string()}]) -> ok.
 usage(OptSpecList, ProgramName, CmdLineTail, OutputStream) when is_atom(OutputStream) ->
-	io:format(OutputStream, "Usage: ~s~s ~s~n~n~s~n",
-              [ProgramName, usage_cmd_line(OptSpecList), CmdLineTail, usage_options(OptSpecList)]);
+    io:format(
+        OutputStream,
+        "Usage: ~s~s ~s~n~n~s~n",
+        [ProgramName, usage_cmd_line(OptSpecList), CmdLineTail, usage_options(OptSpecList)]
+    );
 %% @doc  Show a message on standard_error indicating the command line options and
 %%       arguments that are supported by the program. The CmdLineTail and OptionsTail
 %%       arguments are a string that is added to the end of the usage command line
 %%       and a list of tuples that are added to the end of the options' help lines.
 usage(OptSpecList, ProgramName, CmdLineTail, OptionsTail) ->
-	usage(OptSpecList, ProgramName, CmdLineTail, OptionsTail, standard_error).
-
+    usage(OptSpecList, ProgramName, CmdLineTail, OptionsTail, standard_error).
 
 %% @doc  Show a message on standard_error or standard_io indicating the command line options and
 %%       arguments that are supported by the program. The CmdLineTail and OptionsTail
@@ -508,13 +537,22 @@ usage(OptSpecList, ProgramName, CmdLineTail, OptionsTail) ->
 -spec usage([option_spec()], string(), string(), [{string(), string()}], output_stream()) -> ok.
 usage(OptSpecList, ProgramName, CmdLineTail, OptionsTail, OutputStream) ->
     UsageOptions = lists:foldl(
-                     fun ({Prefix, Help}, Acc) ->
-                             add_option_help(Prefix, Help, Acc)
-                     end, usage_options_reverse(OptSpecList, []), OptionsTail),
-    io:format(OutputStream, "Usage: ~s~s ~s~n~n~s~n",
-              [ProgramName, usage_cmd_line(OptSpecList), CmdLineTail,
-               lists:flatten(lists:reverse(UsageOptions))]).
-
+        fun({Prefix, Help}, Acc) ->
+            add_option_help(Prefix, Help, Acc)
+        end,
+        usage_options_reverse(OptSpecList, []),
+        OptionsTail
+    ),
+    io:format(
+        OutputStream,
+        "Usage: ~s~s ~s~n~n~s~n",
+        [
+            ProgramName,
+            usage_cmd_line(OptSpecList),
+            CmdLineTail,
+            lists:flatten(lists:reverse(UsageOptions))
+        ]
+    ).
 
 %% @doc Return a string with the syntax for the command line options and
 %%      arguments.
@@ -553,7 +591,6 @@ usage_cmd_line([{Name, Short, Long, ArgSpec, _Help} | Tail], Acc) ->
 usage_cmd_line([], Acc) ->
     lists:flatten(lists:reverse(Acc)).
 
-
 %% @doc Return a string with the help message for each of the options and
 %%      arguments.
 -spec usage_options([option_spec()]) -> string().
@@ -586,7 +623,6 @@ usage_options_reverse([{Name, Short, Long, _ArgSpec, Help} | Tail], Acc) ->
 usage_options_reverse([], Acc) ->
     Acc.
 
-
 %% @doc Add the help message corresponding to an option specification to a list
 %%      with the correct indentation.
 -spec add_option_help(Prefix :: string(), Help :: string(), Acc :: string()) -> string().
@@ -605,8 +641,6 @@ add_option_help(Prefix, Help, Acc) when is_list(Help), Help =/= [] ->
 add_option_help(_Opt, _Prefix, Acc) ->
     Acc.
 
-
-
 %% @doc Return the smallest integral value not less than the argument.
 -spec ceiling(float()) -> integer().
 ceiling(X) ->
