@@ -481,7 +481,7 @@ defmodule DesignDocsTest do
         Couch.post("/#{db_name}",
           body: ddoc
         )
-      retry_resp.status_code in [201, 202]
+      assert retry_resp.status_code in [201, 202]
       {:ok, _} = create_doc(db_name, %{_id: "doc1", value: 4})
     end)
   end
